
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'translations_bn.dart';
import 'translations_en.dart';
import 'translations_gu.dart';
import 'translations_hi.dart';
import 'translations_kn.dart';
import 'translations_ml.dart';
import 'translations_mr.dart';
import 'translations_or.dart';
import 'translations_pa.dart';
import 'translations_ta.dart';
import 'translations_te.dart';

/// Callers can lookup localized strings with an instance of Translations returned
/// by `Translations.of(context)`.
///
/// Applications need to include `Translations.delegate()` in their app's
/// localizationDelegates list, and the locales they support in the app's
/// supportedLocales list. For example:
///
/// ```
/// import 'l10n/translations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: Translations.localizationsDelegates,
///   supportedLocales: Translations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the Translations.supportedLocales
/// property.
abstract class Translations {
  Translations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static Translations of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations)!;
  }

  static const LocalizationsDelegate<Translations> delegate = _TranslationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('bn'),
    Locale('en'),
    Locale('gu'),
    Locale('hi'),
    Locale('kn'),
    Locale('ml'),
    Locale('mr'),
    Locale('or'),
    Locale('pa'),
    Locale('ta'),
    Locale('te')
  ];

  /// No description provided for @portFolio.
  ///
  /// In en, this message translates to:
  /// **'Portfolio'**
  String get portFolio;

  /// No description provided for @portfolioDesc.
  ///
  /// In en, this message translates to:
  /// **'Discover, Investments and more'**
  String get portfolioDesc;

  /// No description provided for @discover.
  ///
  /// In en, this message translates to:
  /// **'Discover'**
  String get discover;

  /// No description provided for @investment.
  ///
  /// In en, this message translates to:
  /// **'Investments'**
  String get investment;

  /// No description provided for @homeCardDec2.
  ///
  /// In en, this message translates to:
  /// **'Fractional shares of Top 25 Stocks through ETFs starting as low as ₹100'**
  String get homeCardDec2;

  /// No description provided for @homeCardDec1.
  ///
  /// In en, this message translates to:
  /// **'Select the best Chhotastock suited for your needs'**
  String get homeCardDec1;

  /// No description provided for @funds.
  ///
  /// In en, this message translates to:
  /// **'Funds'**
  String get funds;

  /// No description provided for @noBrokerConnected.
  ///
  /// In en, this message translates to:
  /// **'No broker connected'**
  String get noBrokerConnected;

  /// No description provided for @account.
  ///
  /// In en, this message translates to:
  /// **'Account'**
  String get account;

  /// No description provided for @orders.
  ///
  /// In en, this message translates to:
  /// **'Orders'**
  String get orders;

  /// No description provided for @ordersHistory.
  ///
  /// In en, this message translates to:
  /// **'Order history, status and more'**
  String get ordersHistory;

  /// No description provided for @logoutBroker.
  ///
  /// In en, this message translates to:
  /// **'Logout From Broker'**
  String get logoutBroker;

  /// No description provided for @disconnectYourAccount.
  ///
  /// In en, this message translates to:
  /// **'Disconnect your trading account'**
  String get disconnectYourAccount;

  /// No description provided for @poweredBy.
  ///
  /// In en, this message translates to:
  /// **'Powered by'**
  String get poweredBy;

  /// No description provided for @version.
  ///
  /// In en, this message translates to:
  /// **'Version 1.0'**
  String get version;

  /// No description provided for @pastPerformanceTxt.
  ///
  /// In en, this message translates to:
  /// **'Past performance includes all rebalances & does not include cost or guarantee future returns.'**
  String get pastPerformanceTxt;

  /// No description provided for @loading.
  ///
  /// In en, this message translates to:
  /// **'Loading....'**
  String get loading;

  /// No description provided for @somethingWentWrong.
  ///
  /// In en, this message translates to:
  /// **'Something went wrong.'**
  String get somethingWentWrong;

  /// No description provided for @retry.
  ///
  /// In en, this message translates to:
  /// **'Retry'**
  String get retry;

  /// No description provided for @exitStock.
  ///
  /// In en, this message translates to:
  /// **'Exit from Chhota Stocks'**
  String get exitStock;

  /// No description provided for @investCTA.
  ///
  /// In en, this message translates to:
  /// **'Invest Now'**
  String get investCTA;

  /// No description provided for @orderSubmitted.
  ///
  /// In en, this message translates to:
  /// **'Order Submitted!'**
  String get orderSubmitted;

  /// No description provided for @viewOrder.
  ///
  /// In en, this message translates to:
  /// **'View Orders'**
  String get viewOrder;

  /// No description provided for @emptyBasket.
  ///
  /// In en, this message translates to:
  /// **'No Chhota Stocks available!'**
  String get emptyBasket;

  /// No description provided for @stocksAndWeight.
  ///
  /// In en, this message translates to:
  /// **'Stocks & Weights'**
  String get stocksAndWeight;

  /// No description provided for @overview.
  ///
  /// In en, this message translates to:
  /// **'Overview'**
  String get overview;

  /// No description provided for @chhotaStocksInfo1.
  ///
  /// In en, this message translates to:
  /// **'Constituents of this Chhotastock were last reviewed on Dec 15 2021, and will be next reviewed on the Jan 15 2022'**
  String get chhotaStocksInfo1;

  /// No description provided for @chhotaStocksInfo2.
  ///
  /// In en, this message translates to:
  /// **'Where is it invested?'**
  String get chhotaStocksInfo2;

  /// No description provided for @chhotaStocksInfo3.
  ///
  /// In en, this message translates to:
  /// **'Every unit purchased in this chhotastock is invested in multiple stocks & segments via ETF'**
  String get chhotaStocksInfo3;

  /// No description provided for @chhotaStocksInfo4.
  ///
  /// In en, this message translates to:
  /// **'Chhota Stocks will be added soon!'**
  String get chhotaStocksInfo4;

  /// No description provided for @stocksAndSegment.
  ///
  /// In en, this message translates to:
  /// **'Stocks & Segment'**
  String get stocksAndSegment;

  /// No description provided for @weightage.
  ///
  /// In en, this message translates to:
  /// **'Weightage'**
  String get weightage;

  /// No description provided for @latestNew.
  ///
  /// In en, this message translates to:
  /// **'Latest News'**
  String get latestNew;

  /// No description provided for @news.
  ///
  /// In en, this message translates to:
  /// **'News'**
  String get news;

  /// No description provided for @allBatches.
  ///
  /// In en, this message translates to:
  /// **'All Batches'**
  String get allBatches;

  /// No description provided for @track.
  ///
  /// In en, this message translates to:
  /// **'Track'**
  String get track;

  /// No description provided for @batch.
  ///
  /// In en, this message translates to:
  /// **'Batch'**
  String get batch;

  /// No description provided for @status.
  ///
  /// In en, this message translates to:
  /// **'Status'**
  String get status;

  /// No description provided for @stock.
  ///
  /// In en, this message translates to:
  /// **'Stock'**
  String get stock;

  /// No description provided for @avgPrice.
  ///
  /// In en, this message translates to:
  /// **'Avg Price'**
  String get avgPrice;

  /// No description provided for @qtyFilled.
  ///
  /// In en, this message translates to:
  /// **'Qty Filled'**
  String get qtyFilled;

  /// No description provided for @seeAll.
  ///
  /// In en, this message translates to:
  /// **'See All'**
  String get seeAll;

  /// No description provided for @lastPlacedOn.
  ///
  /// In en, this message translates to:
  /// **'Last placed on'**
  String get lastPlacedOn;

  /// No description provided for @noOrders.
  ///
  /// In en, this message translates to:
  /// **'No Orders Yet!'**
  String get noOrders;

  /// No description provided for @currentVal.
  ///
  /// In en, this message translates to:
  /// **'Current Value'**
  String get currentVal;

  /// No description provided for @totalReturns.
  ///
  /// In en, this message translates to:
  /// **'Total Returns'**
  String get totalReturns;

  /// No description provided for @currentInv.
  ///
  /// In en, this message translates to:
  /// **'Current Investment'**
  String get currentInv;

  /// No description provided for @currentReturns.
  ///
  /// In en, this message translates to:
  /// **'Current Returns'**
  String get currentReturns;

  /// No description provided for @indexVal.
  ///
  /// In en, this message translates to:
  /// **'Index Value'**
  String get indexVal;

  /// No description provided for @details.
  ///
  /// In en, this message translates to:
  /// **'Details'**
  String get details;

  /// No description provided for @investedOn.
  ///
  /// In en, this message translates to:
  /// **'Invested on'**
  String get investedOn;

  /// No description provided for @performance.
  ///
  /// In en, this message translates to:
  /// **'Performance'**
  String get performance;

  /// No description provided for @realizedAndDiv.
  ///
  /// In en, this message translates to:
  /// **'Realized Returns + Dividends'**
  String get realizedAndDiv;

  /// No description provided for @stocksAndETF.
  ///
  /// In en, this message translates to:
  /// **'Stocks/ETFs'**
  String get stocksAndETF;

  /// No description provided for @returns.
  ///
  /// In en, this message translates to:
  /// **'Returns'**
  String get returns;

  /// No description provided for @shares.
  ///
  /// In en, this message translates to:
  /// **'Shares:'**
  String get shares;

  /// No description provided for @noInvestmentYet.
  ///
  /// In en, this message translates to:
  /// **'No Investment Yet!!'**
  String get noInvestmentYet;

  /// No description provided for @openAcc.
  ///
  /// In en, this message translates to:
  /// **'Open Account'**
  String get openAcc;

  /// No description provided for @faqCTA.
  ///
  /// In en, this message translates to:
  /// **'Frequently Asked Questions'**
  String get faqCTA;

  /// No description provided for @disBuySetup.
  ///
  /// In en, this message translates to:
  /// **'Discover, Buy, Setup SIP, Exit & more'**
  String get disBuySetup;

  /// No description provided for @whatIsChhotaSTocks.
  ///
  /// In en, this message translates to:
  /// **'What is a chhotastock?'**
  String get whatIsChhotaSTocks;

  /// No description provided for @faqDesc1.
  ///
  /// In en, this message translates to:
  /// **'They are ready-made baskets allowing you to invest in top 25 well known companies that help you build a low cost, long term and diversified portfolio.'**
  String get faqDesc1;

  /// No description provided for @faqDesc2.
  ///
  /// In en, this message translates to:
  /// **'• Each \"chhotastock\" is managed by Capital Quotient Investment Advisors(SEBI Reg.No: INA200009397) through ETFs that relfect a strategy.'**
  String get faqDesc2;

  /// No description provided for @faqDesc3.
  ///
  /// In en, this message translates to:
  /// **'• You can login with your Broker account and start investing right away.'**
  String get faqDesc3;

  /// No description provided for @faqDesc4.
  ///
  /// In en, this message translates to:
  /// **'For eg: You can invest in Infosys and other top 25 companies in a single basket for ₹100'**
  String get faqDesc4;

  /// No description provided for @faqDesc5.
  ///
  /// In en, this message translates to:
  /// **'What is the minimum investment amount to invest in a chhotastock?'**
  String get faqDesc5;

  /// No description provided for @faqDesc6.
  ///
  /// In en, this message translates to:
  /// **'A minimum investment amount is the current value of the stocks present in a chhotastock along with the prescribed weightage to that intended.\n\n You can also increase the amount you want to invest in that chhotastock by entering any greater amount, and hit confirm to get the closest amount that gives you the right weighting scheme. You would not be able to invest less than the minimum amount.\n\nThe minimum amount for each chhotastock is different & changes in real-time.'**
  String get faqDesc6;

  /// No description provided for @faqDesc7.
  ///
  /// In en, this message translates to:
  /// **'How to place a chhotastock order?'**
  String get faqDesc7;

  /// No description provided for @faqDesc8.
  ///
  /// In en, this message translates to:
  /// **'To begin investing in chhotastock, login with your Broker ID and password, select a chhotastock and get started:'**
  String get faqDesc8;

  /// No description provided for @faqDesc9.
  ///
  /// In en, this message translates to:
  /// **'• After selecting a chhotastock, click on \"Invest Now\" button'**
  String get faqDesc9;

  /// No description provided for @faqDesc10.
  ///
  /// In en, this message translates to:
  /// **'• Choose between Monthly SIP or One Time & confirm the amount'**
  String get faqDesc10;

  /// No description provided for @faqDesc11.
  ///
  /// In en, this message translates to:
  /// **'• Click on \"Confirm Order\" and the order is executed'**
  String get faqDesc11;

  /// No description provided for @faqDesc12.
  ///
  /// In en, this message translates to:
  /// **'• Wait for few seconds and the page automatically redirects to the chhotastock'**
  String get faqDesc12;

  /// No description provided for @faqDesc13.
  ///
  /// In en, this message translates to:
  /// **'Good to know: Once your order is executed all stocks will be credited to your DEMAT account.'**
  String get faqDesc13;

  /// No description provided for @faqDesc14.
  ///
  /// In en, this message translates to:
  /// **'Can I start SIP in chhotastock?'**
  String get faqDesc14;

  /// No description provided for @faqDesc15.
  ///
  /// In en, this message translates to:
  /// **'You can start an SIP in chhotastock in two ways'**
  String get faqDesc15;

  /// No description provided for @faqDesc16.
  ///
  /// In en, this message translates to:
  /// **'• Choose \"Monthly SIP\" when making a fresh investment'**
  String get faqDesc16;

  /// No description provided for @faqDesc17.
  ///
  /// In en, this message translates to:
  /// **'• From your investments, select a smallcase & click on \"Start SIP\"'**
  String get faqDesc17;

  /// No description provided for @faqDesc18.
  ///
  /// In en, this message translates to:
  /// **'Good to know: SIPs are not automatically executed. You will be notified when your SIP is due. Subscribe to WhatsApp updates & never miss an instalment'**
  String get faqDesc18;

  /// No description provided for @faqDesc19.
  ///
  /// In en, this message translates to:
  /// **'Is there a lock-in? How do I exit?'**
  String get faqDesc19;

  /// No description provided for @faqDesc20.
  ///
  /// In en, this message translates to:
  /// **'There are no lock-in periods, you can exit your chhotastock anytime. As a concept however, chhotastock work best when used for long-term investing.'**
  String get faqDesc20;

  /// No description provided for @faqDesc21.
  ///
  /// In en, this message translates to:
  /// **'• You can either exit wholly or partially'**
  String get faqDesc21;

  /// No description provided for @faqDesc22.
  ///
  /// In en, this message translates to:
  /// **'• Select a chhotastock from your “Investments” page'**
  String get faqDesc22;

  /// No description provided for @faqDesc23.
  ///
  /// In en, this message translates to:
  /// **'• Click on Exit chhotastock button & place the order'**
  String get faqDesc23;

  /// No description provided for @faqDesc24.
  ///
  /// In en, this message translates to:
  /// **'Good to know: You can partially exit a chhotastock only when you place an Invest more order.'**
  String get faqDesc24;

  /// No description provided for @faqDesc25.
  ///
  /// In en, this message translates to:
  /// **'Which are the broker platforms currently live with chhotastock?'**
  String get faqDesc25;

  /// No description provided for @faqDesc26.
  ///
  /// In en, this message translates to:
  /// **'We are currently available on the following brokers. If you have an account with any of them, just click on the broker name to log in and explore.'**
  String get faqDesc26;

  /// No description provided for @faqDesc27.
  ///
  /// In en, this message translates to:
  /// **'If you don\'t, you will need to open a Demat & trading account with one of them to invest in chhotastock.'**
  String get faqDesc27;

  /// No description provided for @faqDesc28.
  ///
  /// In en, this message translates to:
  /// **'Good to know: We are live with Kotak Securities, 5paisa and Zerodha for opening a new Demat account'**
  String get faqDesc28;

  /// No description provided for @faqDesc29.
  ///
  /// In en, this message translates to:
  /// **'Demat Account'**
  String get faqDesc29;

  /// No description provided for @faqDesc30.
  ///
  /// In en, this message translates to:
  /// **'Procedure, KYC documents & more'**
  String get faqDesc30;

  /// No description provided for @faqDesc31.
  ///
  /// In en, this message translates to:
  /// **'What is a demat account?'**
  String get faqDesc31;

  /// No description provided for @faqDesc32.
  ///
  /// In en, this message translates to:
  /// **'A Demat account—short for dematerialised account—is an account that allows you to hold company shares and securities electronically.\n\nYou can hold dematerialised securities such as stocks, mutual funds, bonds, exchange-traded funds (ETFs), etc. in a demat account.\n\nSo when you place an order to buy a stock, the shares get credited to your demat account. Similarly, when you choose to sell your shares, they get debited from your demat account.'**
  String get faqDesc32;

  /// No description provided for @faqDesc33.
  ///
  /// In en, this message translates to:
  /// **'How to open a demat account?'**
  String get faqDesc33;

  /// No description provided for @faqDesc34.
  ///
  /// In en, this message translates to:
  /// **'Click on the \"Open Account\" button and follow the steps. Enter the email address, name and phone number and Click on \"Continue\"'**
  String get faqDesc34;

  /// No description provided for @faqDesc35.
  ///
  /// In en, this message translates to:
  /// **'Choose the broker you want to open the Demat account with. Right now, we support opening new DMAT accounts with 3 brokers.'**
  String get faqDesc35;

  /// No description provided for @faqDesc36.
  ///
  /// In en, this message translates to:
  /// **'Once you select the broker you want to open the Demat account with, be ready with the following KYC documents and Click on \"Continue\". You will be redirected to the broker page to complete the rest of the KYC procedures.'**
  String get faqDesc36;

  /// No description provided for @faqDesc37.
  ///
  /// In en, this message translates to:
  /// **'What are the documents required for opening a Demat account?'**
  String get faqDesc37;

  /// No description provided for @faqDesc38.
  ///
  /// In en, this message translates to:
  /// **'You need to verify your PAN, date of birth, bank account number & IFSC Code. You will have to e-verify with the help of Aadhaar. Once verified you will have to upload your signature either signed/scanned on a white sheet or digitally signing on the KYC form.'**
  String get faqDesc38;

  /// No description provided for @faqDesc39.
  ///
  /// In en, this message translates to:
  /// **'Are there any charges for opening a Demat account?'**
  String get faqDesc39;

  /// No description provided for @faqDesc40.
  ///
  /// In en, this message translates to:
  /// **'Every broker have different charges for opening the Demat Account. Right now, we support opening a new account with 3 brokers. You can open a FREE DMAT account with Kotak Securities or 5paisa. Zerodha charges ₹200 for opening a new DMAT Account.'**
  String get faqDesc40;

  /// No description provided for @faqDesc41.
  ///
  /// In en, this message translates to:
  /// **'Add & withdraw funds from your Demat Account'**
  String get faqDesc41;

  /// No description provided for @faqDesc42.
  ///
  /// In en, this message translates to:
  /// **'My available funds are low to place the order, what should I do?'**
  String get faqDesc42;

  /// No description provided for @faqDesc43.
  ///
  /// In en, this message translates to:
  /// **'In the absence of sufficient funds in your trading account, you are requested to add funds and place the order again.'**
  String get faqDesc43;

  /// No description provided for @faqDesc44.
  ///
  /// In en, this message translates to:
  /// **'Chhotastock doesn\'t have separate account for funds. The funds that you have in your broker account will simply reflect here > So add funds to your broker account and place the order in case of insufficient funds.'**
  String get faqDesc44;

  /// No description provided for @faqDesc45.
  ///
  /// In en, this message translates to:
  /// **'How to add funds to my demat account?'**
  String get faqDesc45;

  /// No description provided for @faqDesc46.
  ///
  /// In en, this message translates to:
  /// **'chhotastock doesn\'t have separate account for funds. All your funds are managed by your broker. You can add funds to your Demat account by downloading/visiting your broker application and transfering funds from your mapped bank account using UPI(Google Play, Phonepe, BHIM, etc.) or Net banking'**
  String get faqDesc46;

  /// No description provided for @faqDesc47.
  ///
  /// In en, this message translates to:
  /// **'• How to add funds to my Zerodha account?'**
  String get faqDesc47;

  /// No description provided for @faqDesc48.
  ///
  /// In en, this message translates to:
  /// **'• How to add funds to my Kotak Securities account?'**
  String get faqDesc48;

  /// No description provided for @faqDesc49.
  ///
  /// In en, this message translates to:
  /// **'• How to add funds to my 5paisa account?'**
  String get faqDesc49;

  /// No description provided for @faqDesc50.
  ///
  /// In en, this message translates to:
  /// **'How to withdraw funds from my demat account?'**
  String get faqDesc50;

  /// No description provided for @faqDesc51.
  ///
  /// In en, this message translates to:
  /// **'After you exit any chhotastock either fully or partially, the amount will be credited back to your trading account fund balance. To withdraw, you have to place a withdrawal request with your broker.'**
  String get faqDesc51;

  /// No description provided for @faqDesc52.
  ///
  /// In en, this message translates to:
  /// **'• How to add withdraw funds from my Zerodha account?'**
  String get faqDesc52;

  /// No description provided for @faqDesc53.
  ///
  /// In en, this message translates to:
  /// **'• How to withdraw funds from my Kotak Securities account?'**
  String get faqDesc53;

  /// No description provided for @faqDesc54.
  ///
  /// In en, this message translates to:
  /// **'• How to withdraw funds from my 5paisa account?'**
  String get faqDesc54;

  /// No description provided for @faqDesc55.
  ///
  /// In en, this message translates to:
  /// **'Add & withdraw funds from your Demat Account'**
  String get faqDesc55;

  /// No description provided for @faqDesc56.
  ///
  /// In en, this message translates to:
  /// **'Procedure, KYC documents & more'**
  String get faqDesc56;

  /// No description provided for @dmatAccount.
  ///
  /// In en, this message translates to:
  /// **'Demat Account'**
  String get dmatAccount;

  /// No description provided for @faqDesc57.
  ///
  /// In en, this message translates to:
  /// **'Discover, Buy, Setup SIP, Exit & more'**
  String get faqDesc57;

  /// No description provided for @exitStockLabel.
  ///
  /// In en, this message translates to:
  /// **'Exit from this Chhotastock partially or as a whole.'**
  String get exitStockLabel;

  /// No description provided for @learnCTA.
  ///
  /// In en, this message translates to:
  /// **'Learn'**
  String get learnCTA;

  /// No description provided for @summaryInsightsTxt.
  ///
  /// In en, this message translates to:
  /// **'Summary, insights and more'**
  String get summaryInsightsTxt;

  /// No description provided for @learnDesc1.
  ///
  /// In en, this message translates to:
  /// **'Read, Learn and start your savings journey.'**
  String get learnDesc1;

  /// No description provided for @fundsOrderMore.
  ///
  /// In en, this message translates to:
  /// **'Funds, Orders and more'**
  String get fundsOrderMore;

  /// No description provided for @homeCardPromotionTxt1.
  ///
  /// In en, this message translates to:
  /// **'Create SIP & get stable returns at low risk with minimal fees.'**
  String get homeCardPromotionTxt1;

  /// No description provided for @discoverCS.
  ///
  /// In en, this message translates to:
  /// **'Discover Chhotastock'**
  String get discoverCS;

  /// No description provided for @myCS.
  ///
  /// In en, this message translates to:
  /// **'My Chhotastock'**
  String get myCS;

  /// No description provided for @learnCardTxt1.
  ///
  /// In en, this message translates to:
  /// **'Need help? We are always here!'**
  String get learnCardTxt1;

  /// No description provided for @learnCardTxt2.
  ///
  /// In en, this message translates to:
  /// **'Move forward in your chhotastock journey with these FAQs & Videos'**
  String get learnCardTxt2;
}

class _TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const _TranslationsDelegate();

  @override
  Future<Translations> load(Locale locale) {
    return SynchronousFuture<Translations>(lookupTranslations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['bn', 'en', 'gu', 'hi', 'kn', 'ml', 'mr', 'or', 'pa', 'ta', 'te'].contains(locale.languageCode);

  @override
  bool shouldReload(_TranslationsDelegate old) => false;
}

Translations lookupTranslations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'bn': return TranslationsBn();
    case 'en': return TranslationsEn();
    case 'gu': return TranslationsGu();
    case 'hi': return TranslationsHi();
    case 'kn': return TranslationsKn();
    case 'ml': return TranslationsMl();
    case 'mr': return TranslationsMr();
    case 'or': return TranslationsOr();
    case 'pa': return TranslationsPa();
    case 'ta': return TranslationsTa();
    case 'te': return TranslationsTe();
  }

  throw FlutterError(
    'Translations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
