import 'package:chhota_stocks_flutter/src/core/api/api_endpoints.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/core/models/response_model.dart';
import 'package:chhota_stocks_flutter/src/feature/chartDetails/model/chart_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/model/create_txn_model.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/model/create_txn_type.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/model/init_sdk_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/more_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/news/models/news_model.dart';
import 'package:chhota_stocks_flutter/src/feature/orderStatement/model/order_statement.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_aggregate_model.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_summary_model.dart';
import 'package:chhota_stocks_flutter/src/feature/sipDetails/model/sip_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/transactionCallback/model/transaction_callaback_response.dart';

import 'api_connectivity.dart';
import 'chhota_stocks_api.dart';

class APIService extends APIConnectivity implements ChhotaStocksAPI {
  final String partnerGatewayName =
      ChhotaStocksConfig.getInstance().partnerGatewayName;
  static APIService? _apiService;

  APIService._internal()
      : super(
            baseURL: ChhotaStocksConfig.getInstance().baseURL,
            partnerGatewaySecret:
                ChhotaStocksConfig.getInstance().partnerGatewaySecret);

  static void _initApiService() {
    if (_apiService == null) {
      _apiService = APIService._internal();
    } else {
      throw StateError("API Service is already initialised");
    }
  }

  static APIService getInstance() {
    if (_apiService == null) {
      _initApiService();
    }

    return _apiService!;
  }

  @override
  Future<InitSDKModel> initSDK(String mobile) async {
    try {
      final response = await dio.post(
          ApiEndpoints.initSDK(
              baseURL: dio.options.baseUrl,
              partnerGatewayName: partnerGatewayName),
          data: {"mobile": mobile});


      if (response.statusCode != null && response.statusCode == 200) {
        return InitSDKModel.fromJson(response.data);
      }else if(response.statusCode!=null&&response.statusCode==401){
          return InitSDKModel(status: false,userDoesnotExist: true);
      }else {
        return InitSDKModel.withError(errorMsg: "Something went wrong!");
      }
    } catch (e) {
      return InitSDKModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<DiscoverModel> discover() async {
    try {
      final response = await dio.get(ApiEndpoints.discover(
          baseURL: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName));

      if (response.statusCode != null && response.statusCode == 200) {
        return DiscoverModel.fromJson(response.data);
      } else {
        return DiscoverModel.withError(errorMsg: "Something went wrong!");
      }
    } catch (e) {
      return DiscoverModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<MoreDetailsModel> moreDetails({required String scid}) async {
    try {
      final response = await dio.get(ApiEndpoints.moreDetailsSCID(
          baseURL: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName,
          scid: scid));

      if (response.statusCode != null && response.statusCode == 200) {
        return MoreDetailsModel.fromJson(response.data);
      } else {
        return MoreDetailsModel.withError(errorMsg: "Something went wrong!");
      }
    } catch (e) {
      return MoreDetailsModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<ChartDetailsModel> getChartDetails(
      {required String scid,
      required String benchmarkId,
      String duration = "max"}) async {
    try {
      final response = await dio.get(
          ApiEndpoints.chartDetails(
              baseURL: dio.options.baseUrl,
              partnerGatewayName: partnerGatewayName,
              scid: scid),
          queryParameters: {"benchmarkId": benchmarkId, "duration": duration});

      if (response.statusCode != null && response.statusCode == 200) {
        return ChartDetailsModel.fromJson(response.data);
      } else {
        return ChartDetailsModel.withError(errorMsg: "Something went wrong!");
      }
    } catch (e) {
      return ChartDetailsModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<CreateTxnModel> createTransaction({required String scid,CreateTransactionType createTransactionType=CreateTransactionType.BUY}) async {
    try {
      final response = await dio.get(ApiEndpoints.createTransaction(
          baseURL: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName,
          scid: scid,
         txnType: getTransactionType(createTransactionType),
      ),
      );

      if (response.statusCode != null && response.statusCode == 200) {
        return CreateTxnModel.fromJson(response.data);
      } else {
        return CreateTxnModel.withError(errorMsg: "Something went wrong!");
      }
    } catch (e) {
      return CreateTxnModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<NewsModel> getNews({required String scid}) async {
    try {
      final response = await dio.get(ApiEndpoints.news(
          baseURL: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName,
          scid: scid));

      if (response.statusCode != null && response.statusCode == 200) {
        return NewsModel.fromJson(response.data);
      } else {
        return NewsModel.withError(errorMsg: "Something went wrong");
      }
    } catch (e) {
      return NewsModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<TransactionCallbackResponse> transactionCallback(
      {required String txnId, required String smallcaseAuthId}) async {
    try {
      final response = await dio.post(
          ApiEndpoints.transactionCallback(
              baseURL: dio.options.baseUrl,
              partnerGatewayName: partnerGatewayName,
              transactionId: txnId),
          data: {"smallcaseAuthToken": smallcaseAuthId});
      if (response.statusCode != null && response.statusCode == 200) {
        return TransactionCallbackResponse.fromJson(response.data);
      } else {
        return TransactionCallbackResponse.withError(
            errorMsg: "Something went wrong.");
      }
    } catch (e) {
      return TransactionCallbackResponse.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<ResponseModel> saveLead(
      {required String leadId, required String status}) async {
    try {
      final request = {"leadId": leadId, "status": status};

      final response = await dio.post(
          ApiEndpoints.saveLead(
              baseURL: dio.options.baseUrl,
              partnerGatewayName: partnerGatewayName),
          data: request);

      if (response.statusCode != null && response.statusCode == 200) {
        return ResponseModel.fromJson(response.data);
      } else {
        return ResponseModel.withError(errMsg: "Something went wrong.");
      }
    } catch (e) {
      return ResponseModel.withError(errMsg: e.toString());
    }
  }

  @override
  Future<PortfolioAggregateModel> portfolioAggregate() async {
    try {
      final response = await dio.get(ApiEndpoints.portfolio(
          baseUrl: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName,
          portfolioType: "aggregated"));
      if (response.statusCode != null && response.statusCode == 200) {
        return PortfolioAggregateModel.fromJson(response.data);
      } else {
        return PortfolioAggregateModel.withError();
      }
    } catch (e) {
      return PortfolioAggregateModel.withError(errorMsg: e.toString());
    }
  }

  @override
  Future<PortfolioSummaryModel> portfolioSummary() async {
    try {
      final response = await dio.get(ApiEndpoints.portfolio(
          baseUrl: dio.options.baseUrl,
          partnerGatewayName: partnerGatewayName,
          portfolioType: "summary"));
      if (response.statusCode != null && response.statusCode == 200) {
        return PortfolioSummaryModel.fromJson(response.data);
      } else {
        return PortfolioSummaryModel.withError();
      }
    } catch (e) {
      return PortfolioSummaryModel.withError(errorMsg: e.toString());
    }
  }
  
  
  @override
  Future<OrderStatement> orderStatement()async{
     try{
       final response=await dio.get(ApiEndpoints.statement(baseURL: dio.options.baseUrl, partnerGatewayName: partnerGatewayName));

       if(response.statusCode!=null&&response.statusCode==200){
         return OrderStatement.fromJson(response.data);
       }else{
         return OrderStatement.withError();
       }
     }catch (e){
       return OrderStatement.withError(errMessage: e.toString());
     }
  }

  @override
  Future<CreateTxnModel> brokerFunds()async{
    try{
      final response=await dio.get(ApiEndpoints.brokerFunds(baseURL: dio.options.baseUrl, partnerGatewayName: partnerGatewayName));

      if(response.statusCode!=null&&response.statusCode==200){
        return CreateTxnModel.fromJson(response.data);
      }else{
        return CreateTxnModel.withError();
      }
    }catch (e){
      return CreateTxnModel.withError(errorMsg: e.toString());
    }
  }
  
  
  @override
  Future<SIPDetails> sipDetails({required String iscid})async{
     try{
       final response=await dio.get(ApiEndpoints.sipDetails(baseURL: dio.options.baseUrl, partnerGatewayName: partnerGatewayName, iscid: iscid));

       if(response.statusCode!=null&&response.statusCode==200){
         return SIPDetails.fromJson(response.data);
       }else{
         return SIPDetails.withError();
       }
     }catch (e){
       return SIPDetails.withError(errorMsg: e.toString());
     }
  }
}
