import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

class ChhotaStocksColors{
  static const red1=0xFFffed59;
  static const red2=0xFFffc333;
  static const red3=0xFFff8d40;
  static const red4=0xFFff6337;
  static const red5=0xFFff4031;
}




bool _lightTheme = false;

class ChhotaStocksTheme {
  static const _lightFillColor = Colors.black;
  static const _darkFillColor = Colors.white;

  static final Color _lightFocusColor = Colors.black.withOpacity(0.12);

  // static final Color _darkFocusColor = Colors.white.withOpacity(0.12);

  static ThemeData lightThemeData =
  getThemeData(_lightColorScheme, _lightFocusColor, isLightTheme: true);

  //static ThemeData darkThemeData=getThemeData(_darkColorScheme,_darkFocusColor, isLightTheme: false);

  static ThemeData getThemeData(ColorScheme colorScheme, Color focusColor,
      {bool isLightTheme = true}) {
    _lightTheme = isLightTheme; // to get the light colors from extension
    return ThemeData(
      colorScheme: colorScheme,
      brightness: colorScheme.brightness,
      primaryColor: colorScheme.primary,
      textTheme: _textThemeLight(colorScheme),
            appBarTheme: AppBarTheme(
        backgroundColor: colorScheme.background,
        elevation: 0,
        iconTheme: IconThemeData(color: colorScheme.primary),
        titleTextStyle: TextStyle(color: colorScheme.primary,fontSize: 18.0,fontWeight: FontWeight.w500)
      ),
      iconTheme: IconThemeData(color: colorScheme.primaryVariant),
      canvasColor: colorScheme.background,
      scaffoldBackgroundColor: colorScheme.background,
      highlightColor: Colors.transparent,
      focusColor: focusColor,
      backgroundColor: Colors.white,
      snackBarTheme: SnackBarThemeData(
        behavior: SnackBarBehavior.floating,
        backgroundColor:
        Color.alphaBlend(_lightFillColor.withOpacity(0.80), _darkFillColor),
      ),
    );
  }


   static AppBarTheme customAppBarTheme=const AppBarTheme(
     elevation: 0,
     systemOverlayStyle:  SystemUiOverlayStyle(
       statusBarColor: Color(0xFFF1F1F1),
       statusBarIconBrightness: Brightness.dark,
       statusBarBrightness: Brightness.light,
     ),
     iconTheme:  IconThemeData(
       color: Colors.black, //change your color here
     ),
     backgroundColor:  Color(0xFFF1F1F1),
       titleTextStyle: TextStyle(color: Colors.black,fontSize: 18.0,fontWeight: FontWeight.w500)
  );

  static const ColorScheme _lightColorScheme = ColorScheme(
    primary: Color(0xFF6027d0),
    secondary: Color(0xFFEFF3F3),
    background:Colors.white,
    surface: Color(0xFFFAFBFB),
    onBackground: Colors.white,
    error: _lightFillColor,
    onError: _lightFillColor,
    onPrimary: _lightFillColor,
    onSecondary: Color(0xFF322942),
    onSurface: Color(0xFF241E30),
    brightness: Brightness.light, primaryVariant:  Color(0xFF117378),
    secondaryVariant: Color(0xFFFAFBFB)
  );

  static const _regular = FontWeight.w400;
  static const _medium = FontWeight.w500;
  static const _semiBold = FontWeight.w600; // not used
  static const _bold = FontWeight.w700;

  static TextTheme _textThemeLight(ColorScheme colorScheme) {


  final TextTheme _textTheme = TextTheme(
    headline4: GoogleFonts.montserrat(fontWeight: _bold, fontSize: 20.0),
    caption: GoogleFonts.oswald(fontWeight: _semiBold, fontSize: 16.0),
    headline5: GoogleFonts.oswald(fontWeight: _medium, fontSize: 16.0),
    subtitle1: GoogleFonts.montserrat(fontWeight: _medium, fontSize: 16.0),
    overline: GoogleFonts.montserrat(fontWeight: _medium, fontSize: 12.0),
    bodyText1: GoogleFonts.montserrat(fontWeight: _regular, fontSize: 14.0),
    subtitle2: GoogleFonts.montserrat(fontWeight: _medium, fontSize: 14.0),
    bodyText2: GoogleFonts.montserrat(fontWeight: _regular, fontSize: 16.0),
    headline6: GoogleFonts.montserrat(fontWeight: _bold, fontSize: 16.0),
    button: GoogleFonts.montserrat(fontWeight: _semiBold, fontSize: 14.0),
  );

  return _textTheme;
  }
}

extension colorExtends on ColorScheme {
  static const primaryColorl = Color(0xFF6027d0);
  static const primaryColorLightl = Color(0xFFd1bff3);
  static const darkGrayl = Color(0xFF979797);
  static const greyl = Color(0xFFACACAC);
  static const whitel = Color(0xFFFFFFFF);
  static const redl = Color(0xFFDB3022);
  static const lightGrayl = Color(0xFF9B9B9B);
  static const orangel = Color(0xFFfff5e0);
  static const backgroundLightl = Color(0xFFF9F9F9);
  static const blackl = Color(0xff000000);
  static const popUpBannerGreenl = Color(0xFF19a96a);
  static const popUpBannerRedl = Color(0xFFA12027);
  static const popUpBannerOrangel = Color(0xFFFA6400);
  static const disablel = Color(0xFF929794);
  static const primaryTextColorl = Color(0xFF000000);
  static const primaryTextColorLightl = Color(0xFF464646);
  static const yellowl = Color(0xfffdd856);
  static const lightyellowl = Color(0xffffcf66);
  static const sapphirel = Color(0xff0091ff);
  static const electic_purpll = Color(0xffc526fc);
  static const shadowColorl = Color(0x29747474);
  static const _lightRedColor = Color(0xFFFFF2F2);
  static const _maroonColor = Color(0xFFC76060);
  static const primaryColorD = Color(0xFF6027d0);
  static const primaryColorLightD = Color(0xFFd1bff3);
  static const darkGrayD = Color(0xFF979797);
  static const greyD = Color(0xFFACACAC);
  static const whiteD = Color(0x00FFFFFF);
  static const redD = Color(0xFFDB3022);
  static const lightGrayD = Color(0xFF9B9B9B);
  static const orangeD = Color(0xFFFFBA49);
  static const backgroundLightD = Color(0xFFF9F9F9);
  static const blackD = Color(0x00000000);
  static const popUpBannerGreenD = Color(0xFF53CC73);
  static const popUpBannerRedD = Color(0xFFA12027);
  static const popUpBannerOrangeD = Color(0xFFFA6400);
  static const disableD = Color(0xFF929794);
  static const primaryTextColorD = Color(0xFF000000);
  static const primaryTextColorLightD = Color(0xFF464646);
  static const yellowD = Color(0xfffdd856);
  static const lightyellowD = Color(0xffffcf66);
  static const sapphireD = Color(0xff0091ff);
  static const electic_purpleD = Color(0xffc526fc);
  static const shadowColorD = Color(0x29747474);
  static const yellowColor = Color(0xFFFFCF66);
  static const _secondaryCardColor = Color(0xFF6F77FB);
  static const _purple = Color(0xFF8052d9);
  static const _purple4 = Color(0xFFF9F7Fd);
  static const _indigo = Color(0xFF1A3dA3);
  static const _lightBlack = Color(0xFFF1F4FF);
  static const _lightGreen = Color(0xFFEFFFFA);
  static const _darkGreen = Color(0xFF258C6E);
  static const _lightIndigo = Color(0xffdddfff);
  static const _indigoDark = Color(0xff454dc5);
  static const _lightblue = Color(0xfff9faff);
  static const lightTextColorL = Color(0xFF747474);
  static const lightTextColorD = Color(0xFF747474);
  static const _offGreen = Color(0xffecfff7);
  static const _fairPink = Color(0xfffff2ec);
  static const _peachCream = Color(0xfffff1e6);
  static const _bottomSheetShadow = Color(0x29000000);
  static const _lightGreenCardColor = Color(0xFFe5fbf7);
  static const _blackishCardColor = Color(0xd9000000);
  static const _violetColor = Color(0xff6f3cd4);
  static const _lightGreyColor = Color(0xffadadad);
  static const _tomatoRedColor = Color(0xffcd5f4f);
  static const _lightGrey2Color = Color(0xff5c5c5c);
  static const _yellowDarkColor = Color(0xfffdd855);
  static const _redColor = Color(0xffce2d22);
  static const _darkGreenColor = Color(0xff082d0f);
  static const _brownColor = Color(0xff502419);
  static const _steelBlueColor = Color(0xff104c72);
  static const _ruriBlueColor = Color(0xffce2d22);
  static const _darkGrey = Color(0xff181818);
  static const _greenTeal = Color(0xffedfff0);
  static const _lavaRed = Color(0xffe02020);
  static const _tealishBlue = Color(0xfff0f3fc);
  static const _whiteLilac = Color(0xfff7f9ff);
  static const _primaryCtaBorderL = Color(0xFFdfd4f6);
  static const _primaryCtaBorderD = Color(0xFFdfd4f6);
  static const _deliveryCardBgColorL = Color(0xFFF0F4FF);
  static const _deliveryCardBgColorD = Color(0xFFF0F4FF);
  static const _deliveryCardCTABgColorL = Color(0xFF1e49be);
  static const _deliveryCardCTABgColorD = Color(0xFF1e49be);
  static const _sunShade = Color(0xffeea422);
  static const _deepBronze = Color(0xff502e0d);
  static const _paleOrange = Color(0xffe8b459);
  static const _mediumBrown = Color(0xff7d4814);
  static const _ghostWhite = Color(0xfff5f8ff);
  static const _softGreen = Color(0xff5cbc92);
  static const _softRed = Color(0xffeb5858);
  static const _coralPink = Color(0xffed8787);
  static const _greenPea = Color(0xff2c694e);
  static const _paleBlue = Color(0xffbdcbeb);
  static const _oceanBlue = Color(0xff007eae);
  static const _iceGreen = Color(0xffdef5ed);
  static const _planInfoMetaWidgetBgColorL = Color(0xFFF9F6FD);
  static const _planInfoMetaWidgetBgColorD = Color(0xFFF9F6FD);

  Color get lightGreenCardColor => _lightGreenCardColor;

  Color get tomatoRedColor => _tomatoRedColor;

  Color get darkGreenColor => _darkGreenColor;

  Color get brownColor => _brownColor;

  Color get steelBlueColor => _steelBlueColor;

  Color get ruriBlueColor => _ruriBlueColor;

  Color get redColor => _redColor;

  Color get yellowDarkColor => _yellowDarkColor;

  Color get blackishCardColor => _blackishCardColor;

  Color get lightGrey2Color => _lightGrey2Color;

  Color get lightGreyColor => _lightGreyColor;

  Color get violetColor => _violetColor;

  Color get secondaryCardColor => _secondaryCardColor;

  Color get primaryColor => _lightTheme ? primaryColorl : primaryColorD;

  Color get primaryColorLight =>
      _lightTheme ? primaryColorLightl : primaryColorLightD;

  Color get darkGray => _lightTheme ? darkGrayl : darkGrayD;

  Color get grey => _lightTheme ? greyl : greyD;

  Color get white => _lightTheme ? whitel : whiteD;

  Color get red => _lightTheme ? redl : redD;

  Color get lightGray => _lightTheme ? lightGrayl : lightGrayD;

  Color get orange => _lightTheme ? orangel : orangeD;

  Color get purple => _purple;

  Color get backgroundLight =>
      _lightTheme ? backgroundLightl : backgroundLightD;

  Color get lightRedColor => _lightRedColor;

  Color get black => _lightTheme ? blackl : blackD;

  Color get popUpBannerGreen =>
      _lightTheme ? popUpBannerGreenl : popUpBannerGreenD;

  Color get popUpBannerRed => _lightTheme ? popUpBannerRedl : popUpBannerRedD;

  Color get popUpBannerOrange =>
      _lightTheme ? popUpBannerOrangel : popUpBannerOrangeD;

  Color get disable => _lightTheme ? disablel : disableD;

  Color get primaryTextColor =>
      _lightTheme ? primaryTextColorl : primaryTextColorD;

  Color get primaryTextColorLight =>
      _lightTheme ? primaryTextColorLightl : primaryTextColorLightD;

  Color get yellow => _lightTheme ? yellowl : yellowD;

  Color get lightyellow => _lightTheme ? lightyellowl : lightyellowD;

  Color get sapphire => _lightTheme ? sapphirel : sapphireD;

  Color get electic_purpl => _lightTheme ? electic_purpll : electic_purpleD;

  Color get shadowColor => _lightTheme ? shadowColorl : shadowColorD;

  Color get yellowCardColor => yellowColor;

  Color get maroonColor => _maroonColor;

  Color get purple4 => _purple4;

  Color get indigo => _indigo;

  Color get lightBlack => _lightBlack;

  Color get lightGreen => _lightGreen;

  Color get darkGreen => _darkGreen;

  Color get indigoDark => _indigoDark;

  Color get lightIndigo => _lightIndigo;

  Color get lightTextColor => _lightTheme ? lightTextColorL : lightTextColorD;

  Color get bottomSheetShadow => _bottomSheetShadow;

  Color get lightblue => _lightblue;

  Color get lightPurple => primaryColorD;

  Color get offGreen => _offGreen;

  Color get fairPink => _fairPink;

  Color get primaryCtaBorder =>
      _lightTheme ? _primaryCtaBorderL : _primaryCtaBorderD;

  Color get deliveryCardBgColor =>
      _lightTheme ? _deliveryCardBgColorL : _deliveryCardBgColorD;

  Color get deliveryCardCTABgColor =>
      _lightTheme ? _deliveryCardCTABgColorL : _deliveryCardCTABgColorD;

  Color get peachCream => _peachCream;

  Color get darkGrey => _darkGrey;

  Color get greenTeal => _greenTeal;

  Color get lavaRed => _lavaRed;

  Color get tealishBlue => _tealishBlue;

  Color get whiteLilac => _whiteLilac;

  Color get sunShade => _sunShade;

  Color get deepBronze => _deepBronze;

  Color get paleOrange => _paleOrange;

  Color get mediumBrown => _mediumBrown;

  Color get ghostWhite => _ghostWhite;

  Color get softGreen => _softGreen;

  Color get softRed => _softRed;

  Color get coralPink => _coralPink;

  Color get greenPea => _greenPea;

  Color get paleBlue => _paleBlue;

  Color get iceGreen => _iceGreen;

  Color get oceanBlue => _oceanBlue;
  Color get planInfoMetaWidgetBgColor =>
      _lightTheme ? _planInfoMetaWidgetBgColorL : _planInfoMetaWidgetBgColorD;
}
