import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/ui/funds_card.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/bloc/init_sdk_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/home_app_bar.dart';
import 'package:chhota_stocks_flutter/src/feature/orderStatement/ui/order_statement_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/saveLead/ui/lead_gen_btn.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

class AccountHomeWidget extends StatelessWidget {
  const AccountHomeWidget({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<InitSdkCubit, InitSdkState>(builder: (context, state) {
      if (state is InitSdkSuccess) {
        return _AccountHomeWidget(
          getFundsTxnId: state.fundsTransaction?.transactionId,
          isGuestUser: state.isGuestUser,
        );
      }

      return const SizedBox();
    });
  }
}


class _AccountHomeWidget extends StatefulWidget {
  final String? getFundsTxnId;
  final bool isGuestUser;
  const _AccountHomeWidget({Key? key, this.getFundsTxnId,required this.isGuestUser}) : super(key: key);

  @override
  State<_AccountHomeWidget> createState() => _AccountHomeWidgetState();
}

class _AccountHomeWidgetState extends State<_AccountHomeWidget> {
  @override
  void initState() {
    super.initState();

    // if (widget.getFundsTxnId != null && widget.getFundsTxnId!.isNotEmpty) {
    //   BlocProvider.of<FundsCubit>(context)
    //       .getFundDetails(widget.getFundsTxnId!);
    // }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: accountAppBar,
        body: ListView(children: [
          const SizedBox(
            height: 20,
          ),

          const Padding(
            padding:
                 EdgeInsets.symmetric(horizontal: 18.0, vertical: 0.0),
            child:  FundsCard(),
          ),
          const SizedBox(
            height: 12,
          ),
          Padding(
            padding:
                const EdgeInsets.symmetric(horizontal: 18.0, vertical: 9.0),
            child: Column(
              children: [
                if(widget.isGuestUser)const LeadGenButton(isProfileBtn: true,),
                if (!widget.isGuestUser)  const _OrderCard(),
                if (!widget.isGuestUser) const _LogoutCard(),
                const SizedBox(),
              ],
            ),
          ),
          SizedBox(
            height: MediaQuery.of(context).size.height * 0.1,
          ),
          Opacity(
            opacity: 0.35,
            child: Container(
              padding: const EdgeInsets.symmetric(vertical: 25.0),
              child: Column(
                children: [
                  Text(
                    Translations.of(context).poweredBy,
                    //"Powered by",
                    style: TextStyle(fontSize: 11.0),
                  ),
                  const SizedBox(
                    height: 7,
                  ),
                  SvgPicture.network(
                    "https://assets.chhotastock.com/app/chhota-stock-textbelow-light.svg",
                    width: 75,
                  ),
                  const SizedBox(
                    height: 5,
                  ),
                  Text(
                    Translations.of(context).version,
                    //"Version 1.0",
                    style: const TextStyle(fontSize: 9.0),
                  ),
                ],
              ),
            ),
          )
        ]));
  }
}

class _OrderCard extends StatelessWidget {
  const _OrderCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        InkWell(
          onTap: () => Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => const OrderStatmentWidget())),
          child: ListTile(
            title: Text(
              Translations.of(context).orders,
              // "Orders",
              style: const TextStyle(
                fontWeight: FontWeight.w400,
                fontSize: 16.0,
              ),
            ),
            subtitle: Text(
              Translations.of(context).ordersHistory,
              //"Order history, status and more",
              style: const TextStyle(
                fontWeight: FontWeight.normal,
                fontSize: 11.0,
              ),
            ),
            trailing: const Icon(
              Icons.arrow_forward_ios_rounded,
              size: 20,
            ),
          ),
        ),
        const Divider(
          height: 4.0,
        ),
      ],
    );
  }
}

class _LogoutCard extends StatelessWidget {
  const _LogoutCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        InkWell(
          onTap: () => ScgatewayFlutterPlugin.logoutUser(),
          child: ListTile(
            title: Text(
              Translations.of(context).logoutBroker,
              //"Logout From Broker",
              style: const TextStyle(
                fontWeight: FontWeight.w400,
                fontSize: 16.0,
              ),
            ),
            subtitle: Text(
              Translations.of(context).disconnectYourAccount,
              // "Disconnect your trading account",
              style: const TextStyle(
                fontWeight: FontWeight.w300,
                fontSize: 11.0,
              ),
            ),
            trailing: const Icon(
              Icons.logout,
              size: 20,
            ),
          ),
        ),
        const Divider(
          height: 4.0,
        ),
      ],
    );
  }
}
