import 'package:intl/intl.dart';
import 'package:json_annotation/json_annotation.dart';

part 'chart_details_model.g.dart';

@JsonSerializable()
class ChartDetailsModel {
  int? code;
  String? error;
  bool? status;
  @JsonKey(name: "result")
  ChartDetailsResult? chartDetailsResult;



  ChartDetailsModel(
      {this.code, this.error, this.status, this.chartDetailsResult});

  ChartDetailsModel.withError({required String errorMsg}):this.error=errorMsg;


  factory ChartDetailsModel.fromJson(Map<String, dynamic> json) =>
      _$ChartDetailsModelFromJson(json);
}

@JsonSerializable()
class ChartDetailsResult {
  bool? success;
  String? errors;

  @JsonKey(name: "data")
  ChartDetailsData? chartDetailsData;

  ChartDetailsResult({this.chartDetailsData, this.success, this.errors});

  factory ChartDetailsResult.fromJson(Map<String, dynamic> json) =>
      _$ChartDetailsResultFromJson(json);
}

@JsonSerializable()
class ChartDetailsData {
  String? defaultDuration;
  BenchMark? benchmark;

  List<String>? durations;

  SmallCaseChartDetails? smallcase;

  ChartDetailsData(
      {this.benchmark, this.defaultDuration, this.smallcase, this.durations});

  factory ChartDetailsData.fromJson(Map<String, dynamic> json) =>
      _$ChartDetailsDataFromJson(json);
}

@JsonSerializable()
class SmallCaseChartDetails {
  List<Points>? points;
  String? scid;

  SmallCaseChartDetails({this.points, this.scid});

  factory SmallCaseChartDetails.fromJson(Map<String, dynamic> json) =>
      _$SmallCaseChartDetailsFromJson(json);
}

@JsonSerializable()
class BenchMark {
  String? benchmarkId;
  String? benchmarkLabel;
  String? id;
  String? index;
  String? message;
  String? msg;

  List<Points>? points;
  BenchMark({this.benchmarkId, this.benchmarkLabel, this.points,this.id,this.index,this.msg,this.message});
  factory BenchMark.fromJson(Map<String, dynamic> json) =>
      _$BenchMarkFromJson(json);
}

@JsonSerializable()
class Points {
  String? date;
  num? value;

  String? get getYear=>this.date!=null&&this.date!.isNotEmpty?DateTime.parse(this.date!).year.toString():null;

  String? durationString(String val){
    final filter=val.toLowerCase();
    if(this.date==null||this.date!.isEmpty){
     return null;
    }else if(val.contains("m")||val.contains("live")){
     final dateTime= DateTime.parse(this.date!);
     final formatter=DateFormat("dd MMM yy");
     return formatter.format(dateTime);
    }else{
      return DateTime.parse(this.date!).year.toString();
    }
  }

  Points({this.date, this.value});
  factory Points.fromJson(Map<String, dynamic> json) => _$PointsFromJson(json);
}
