import 'package:chhota_stocks_flutter/src/feature/chartDetails/bloc/chart_details_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class ChartFilter extends StatelessWidget {
  const ChartFilter({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ChartDetailsCubit, ChartDetailsState>(
        builder: (context, state) {
      if (state is ChartDetailsSuccess &&
          state.chartDetailsData.benchmark?.points != null &&
          state.chartDetailsData.durations != null &&
          state.chartDetailsData.durations!.isNotEmpty) {
        return _ChartFilter(
          durations: state.chartDetailsData.durations!,
          selectedFilter: state.chartFilter,
        );
      }

      return const SizedBox();
    });
  }
}

class _ChartFilter extends StatelessWidget {
  final List<String> durations;
  final String selectedFilter;

  _ChartFilter(
      {Key? key, required this.durations, required this.selectedFilter})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      children: durations.map((e) {
        return _TextContainer(
          onTap: () => BlocProvider.of<ChartDetailsCubit>(context)
              .filterChart(duration: e),
          text: e,
          isSelected: e == selectedFilter,
        );
      }).toList(),
    );
  }
}

class _TextContainer extends StatelessWidget {
  final VoidCallback onTap;
  final String text;
  final bool isSelected;
  const _TextContainer(
      {Key? key,
      required this.onTap,
      required this.text,
      this.isSelected = false})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Container(
        height: 35,
        width: 40,
        alignment: Alignment.center,
        decoration: BoxDecoration(
          border: Border.all(color: Colors.grey),
          color: isSelected ? Theme.of(context).secondaryHeaderColor : null,
        ),
        child: Text(
          text.toUpperCase(),
          overflow: TextOverflow.ellipsis,
          style: const TextStyle(
            fontSize: 12.0,
          ),
        ),
      ),
    );
  }
}
