import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/chartDetails/bloc/chart_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/chartDetails/model/chart_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

class ChartOverview extends StatelessWidget {
  const ChartOverview({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ChartDetailsCubit, ChartDetailsState>(
        builder: (context, state) {
      if (state is ChartDetailsSuccess &&
          state.chartDetailsData.benchmark?.points != null &&
          state.chartDetailsData.smallcase!.points != null) {
        return Center(
          child: Column(children: [
            SfCartesianChart(
                // Initialize category axis
                primaryXAxis: CategoryAxis(
                  majorGridLines: MajorGridLines(width: 0),
                ),
                title: ChartTitle(
                    text:
                        "Performance vs ${state.chartDetailsData.benchmark?.benchmarkLabel ?? ""}",
                    textStyle: const TextStyle(
                      fontSize: 12.0,
                      color: Colors.black,
                      fontWeight: FontWeight.normal,
                    )),
                tooltipBehavior: TooltipBehavior(enable: true),
                series: <LineSeries<Points, String>>[
                  LineSeries<Points, String>(
                      color: Color(0xFFee4925),
                      // Bind data source
                      dataSource: <Points>[
                        ...state.chartDetailsData.benchmark!.points!,
                      ],
                      enableTooltip: true,
                      name: state.chartDetailsData.benchmark?.benchmarkLabel ??
                          "",
                      xValueMapper: (Points points, _) =>
                          points.durationString(state.chartFilter),
                      yValueMapper: (Points points, _) => points.value),
                  LineSeries<Points, String>(
                      color: Color(0xFF1f7ae0),
                      // Bind data source
                      dataSource: <Points>[
                        ...state.chartDetailsData.smallcase!.points!
                      ],
                      enableTooltip: true,
                      name: state.chartDetailsData.smallcase?.scid ?? "",
                      xValueMapper: (Points points, _) =>
                          points.durationString(state.chartFilter),
                      yValueMapper: (Points points, _) => points.value)
                ]),
            Text(
              Translations.of(context).pastPerformanceTxt,
             // "Past performance includes all rebalances & does not include cost or guarantee future returns.",
              textAlign: TextAlign.center,
              style: TextStyle(
                color: Colors.grey,
                fontSize: 11.0,
              ),
            )
          ]),
        );
      } else if (state is ChartDetailsLoading) {
        return Container(
            height: 200,
            alignment: Alignment.center,
            child:const Loader());
      }

      return  Text(
          Translations.of(context).loading
          //"Loading...."
          );
    });
  }
}
