import 'dart:math' as pi;

import 'package:chhota_stocks_flutter/src/core/theme/theme.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';

class LoadingAnimation extends StatefulWidget {
  const LoadingAnimation({Key? key}) : super(key: key);
  @override
  _LoadingAnimationState createState() => _LoadingAnimationState();
}

class _LoadingAnimationState extends State<LoadingAnimation>
    with SingleTickerProviderStateMixin, AutomaticKeepAliveClientMixin {
  late Animation<double> _angleAnimation;

  late Animation<double> _scaleAnimation;

  late AnimationController _controller;

  @override
  bool get wantKeepAlive => true;

  @override
  void initState() {
    super.initState();

    if (mounted) {
      _controller = AnimationController(
          duration: const Duration(milliseconds: 2000), vsync: this);
      _angleAnimation = Tween(begin: 0.0, end: 360.0).animate(_controller)
        ..addListener(() {
          setState(() {
            // the state that has changed here is the animation object’s value
          });
        });
      _scaleAnimation = Tween(begin: 1.0, end: 6.0).animate(_controller)
        ..addListener(() {
          setState(() {
            // the state that has changed here is the animation object’s value
          });
        });

      _controller.forward();
    }
  }

  @override
  void dispose() {
    if (_controller != null) {
      _controller.dispose();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // return Center(child: _buildAnimation());
    return Center(
      child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            SvgPicture.network(
              "https://assets.chhotastock.com/app/chhota-stock-only-logo.svg",
              height: 60,
              width: 60,
            ),
            const SizedBox(
              height: 10,
            ),
            const Text("Loading..."),
          ]),
    );
  }

  Widget _buildAnimation() {
    double circleWidth = 10.0 * _scaleAnimation.value;
    Widget circles = Container(
      width: circleWidth * 2.0,
      height: circleWidth * 2.0,
      child: Column(
        children: <Widget>[
          Row(
            children: <Widget>[
              BuildCircle(circleWidth: circleWidth, color: Colors.red),
              BuildCircle(
                  circleWidth: circleWidth,
                  color: Colors.grey.withOpacity(0.1)),
            ],
          ),
          Row(
            children: <Widget>[
              BuildCircle(
                  circleWidth: circleWidth,
                  color: Colors.grey.withOpacity(0.1)),
              BuildCircle(circleWidth: circleWidth, color: Colors.redAccent),
            ],
          ),
        ],
      ),
    );

    double angleInDegrees = _angleAnimation.value;
    return Transform.rotate(
      angle: angleInDegrees / 360 * 2 * pi.pi,
      child: Container(
        child: circles,
      ),
    );
  }
}

class BuildCircle extends StatelessWidget {
  final double circleWidth;
  final Color color;

  const BuildCircle({Key? key, required this.circleWidth, required this.color})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: circleWidth,
      height: circleWidth,
      decoration: BoxDecoration(
        color: color,
        shape: BoxShape.circle,
      ),
    );
  }
}
