import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/create_txn_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/trigger_txn_method.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/model/create_txn_type.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/ui/txn_loader.dart';
import 'package:chhota_stocks_flutter/src/feature/transactionCallback/bloc/transaction_callback_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

class ExitButtton extends StatelessWidget {
  final String iscid;
  const ExitButtton({Key? key, required this.iscid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
      providers: [
        BlocProvider<TransactionCallbackCubit>(
            create: (_) => TransactionCallbackCubit()),
        BlocProvider<CreateTxnCubit>(create: (_) => CreateTxnCubit()),
      ],
      child: _ExitBtn(scid: iscid),
    );
  }
}

class _ExitBtn extends StatelessWidget {
  final String scid;
  const _ExitBtn({Key? key, required this.scid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocConsumer<CreateTxnCubit, CreateTxnState>(
      listener: (context, state) {
        if (state is CreateTxnSuccess && state.txnData.transactionId != null) {
          triggerTxnMethod(context: context,txnId: state.txnData.transactionId!);

        } else if (state is CreateTxnError) {
          // Fluttertoast.showToast(msg: state.errorMsg);
        }
      },
      builder: (context, state) {
        return Container(
            padding: EdgeInsets.symmetric(horizontal: 18.0, vertical: 10.0),
            color: const Color(0xFFF1F1F1),
            child: Row(children: [
              Flexible(
                child: Text(
                  Translations.of(context).exitStockLabel,
                  style:const  TextStyle(
                    fontSize: 13.0,
                    fontWeight: FontWeight.w400,
                    color: Colors.grey,
                  ),
                ),
              ),
              const SizedBox(
                width: 15,
              ),
              ElevatedButton(
                  style: ButtonStyle(
                      backgroundColor:
                      MaterialStateProperty.all<Color>(Colors.white),
                      shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                          RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0),
                              side: const BorderSide(color: Colors.red)))),
                  onPressed: () => BlocProvider.of<CreateTxnCubit>(context)
                      .createTransaction(
                      scid: scid,
                      createTransactionType: CreateTransactionType.EXIT),
                  child: state is CreateTxnLoading
                      ? Container(
                    height: 50,
                    alignment: Alignment.center,
                    child: const CircularProgressIndicator(
                      color: Colors.red,
                    ),
                  )
                      : Text(
                    Translations.of(context).exitStock,
                    //"Exit from Chhota Stocks",
                    overflow: TextOverflow.ellipsis,
                    style: const TextStyle(
                      color: Colors.red,
                      fontWeight: FontWeight.w400,
                    ),
                  ))
            ]));
      },
    );
  }
}
