import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/create_txn_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/trigger_txn_method.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/ui/txn_loader.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/bloc/more_details_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

class InvestButtton extends StatelessWidget {
  final String scid;
  const InvestButtton({Key? key, required this.scid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<MoreDetailsCubit, MoreDetailsState>(
        builder: (context, state) {
      if (state is MoreDetailsSuccess) {
        return MultiBlocProvider(
          providers: [
            BlocProvider<CreateTxnCubit>(create: (_) => CreateTxnCubit()),
          ],
          child: _InvestButton(scid: scid),
        );
      }

      return const SizedBox();
    });
  }
}

class _InvestButton extends StatelessWidget {
  final String scid;
  const _InvestButton({Key? key, required this.scid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocConsumer<CreateTxnCubit, CreateTxnState>(
      listener: (context, state) {
        if (state is CreateTxnSuccess && state.txnData.transactionId != null) {
          triggerTxnMethod(context: context,txnId: state.txnData.transactionId!);
        } else if (state is CreateTxnError) {
          // Fluttertoast.showToast(msg: state.errorMsg);
        }
      },
      builder: (context, state) {
        return FloatingActionButton.extended(
            isExtended: true,
            materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
            backgroundColor: const Color(0xFF6027d0),
            extendedTextStyle: const TextStyle(
              color: Colors.white,
              fontWeight: FontWeight.bold,
            ),
            disabledElevation: 0,
            shape:
                const BeveledRectangleBorder(borderRadius: BorderRadius.zero),
            label: state is CreateTxnLoading
                ? Container(
                    width: MediaQuery.of(context).size.width,
                    child: const Center(
                      child: CircularProgressIndicator(
                        color: Colors.white,
                      ),
                    ))
                : Container(
                    width: MediaQuery.of(context).size.width,
                    child: Text(
                      Translations.of(context).investCTA,
                      // "Invest Now",
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 16.0,
                        fontWeight: FontWeight.w400,
                      ),
                    ),
                  ),
            onPressed: () => state is CreateTxnLoading
                ? null
                : BlocProvider.of<CreateTxnCubit>(context)
                    .createTransaction(scid: scid));
      },
    );
  }
}
