import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/create_txn_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/bloc/trigger_txn_method.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/model/create_txn_type.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:shimmer/shimmer.dart';

import '../../transactionCallback/bloc/transaction_callback_cubit.dart';

class SIPButton extends StatelessWidget {
  final String iscid;
  const SIPButton({Key? key, required this.iscid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
      providers: [
        BlocProvider<CreateTxnCubit>(create: (_) => CreateTxnCubit()),
      ],
      child: _SIPButton(iscid: iscid),
    );
  }
}

class _SIPButton extends StatelessWidget {
  final String iscid;
  const _SIPButton({Key? key, required this.iscid}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocConsumer<CreateTxnCubit, CreateTxnState>(
      listener: (context, state) {
        if (state is CreateTxnSuccess && state.txnData.transactionId != null) {
          triggerTxnMethod(context: context,txnId: state.txnData.transactionId!);
        } else if (state is CreateTxnError) {
          // Fluttertoast.showToast(msg: state.errorMsg);
        }
      },
      builder: (context, state) {
        if(state is CreateTxnLoading){
          return Column(
            children: const [
              ShimmerLoader(
                height: 50,

              ),
              Divider(color: Color(0xFFdde0e4),),
            ],
          );
        }
        return InkWell(
          onTap: () => state is CreateTxnLoading
              ? null
              : BlocProvider.of<CreateTxnCubit>(context)
              .createTransaction(scid: iscid,createTransactionType: CreateTransactionType.INVESTMORE),
          child:  Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const SizedBox(height: 12,),
              Row(
                children: const [
                  Icon(Icons.sip,size: 20,),
                  SizedBox(width: 12.0,),
                  Text("Start SIP"),
                ],),

              const SizedBox(height: 12,),

              const Divider(color: Color(0xFFdde0e4),),
            ],
          )


        );



      },
    );
  }
}


class SipPendingActionBtn extends StatelessWidget {
  final String iscid;
  const SipPendingActionBtn({Key? key,required this.iscid}):super(key: key);
  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
      providers: [
        BlocProvider<TransactionCallbackCubit>(
            create: (_) => TransactionCallbackCubit()),
        BlocProvider<CreateTxnCubit>(create: (_) => CreateTxnCubit()),
      ],
      child: _SipPendingAction(iscid: iscid),
    );
  }
}

class _SipPendingAction extends StatelessWidget {
  final String iscid;
  const _SipPendingAction({Key? key,required this.iscid}):super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<CreateTxnCubit, CreateTxnState>(
      listener: (context, state) {
        if (state is CreateTxnSuccess && state.txnData.transactionId != null) {
          triggerTxnMethod(context:context,txnId: state.txnData.transactionId!);

        } else if (state is CreateTxnError) {
          // Fluttertoast.showToast(msg: state.errorMsg);
        }
      },
      builder: (context, state) {
        if(state is CreateTxnLoading){
          return Shimmer.fromColors(
            highlightColor:  Colors.green.withOpacity(0.4),
            baseColor: Colors.green.withOpacity(0.6),
            child: Container(
              width: double.infinity,

              decoration: const BoxDecoration(
                  color:  Colors.green,
                  borderRadius: BorderRadius.only(bottomRight: Radius.circular(10.0),bottomLeft: Radius.circular(10.0))
              ),
              child: const Padding(
                padding:  EdgeInsets.symmetric(vertical: 12.0),
                child:  Text(
                  "Loading...",
                  textAlign: TextAlign.center,
                  overflow: TextOverflow.ellipsis,
                  style: TextStyle(
                      fontSize: 12.0,
                      fontWeight: FontWeight.w400,
                      color: Colors.white
                  ),
                ),
              ),


            ),
          );
        }
        return InkWell(
            onTap:() => state is CreateTxnLoading
                ? null
                : BlocProvider.of<CreateTxnCubit>(context)
                .createTransaction(scid: iscid,createTransactionType: CreateTransactionType.INVESTMORE),
            child:Container(
              width: double.infinity,
              decoration: const BoxDecoration(
                  color:  Colors.green,
                  borderRadius: BorderRadius.only(bottomRight: Radius.circular(10.0),bottomLeft: Radius.circular(10.0))
              ),
              child: Padding(
                padding:  const EdgeInsets.symmetric(vertical: 12.0,horizontal: 12.0),
                child:  Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: const [
                    Text(
                      "Setup SIP",
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                          fontSize: 14.0,
                          fontWeight: FontWeight.w400,
                          color: Colors.white
                      ),
                    ),
                    CircleAvatar(
                      backgroundColor: Colors.white,
                        radius: 16,
                        child: Icon(Icons.arrow_forward_ios_rounded,color: Colors.green,size: 20,))
                  ],
                ),
              ),
            ));


      },
    );
  }
}
