import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_summary_model.dart';
import 'package:json_annotation/json_annotation.dart';
part 'discover_model.g.dart';

@JsonSerializable()
class DiscoverModel {
  int? code;
  String? error;
  bool? status;
  String? errorMsg;

  @JsonKey(name: "result")
  DiscoverResult? discoverResult;

  DiscoverModel({this.code, this.error, this.status, this.discoverResult});

  DiscoverModel.withError({required String errorMsg})
      : this.errorMsg = errorMsg;

  factory DiscoverModel.fromJson(Map<String, dynamic> json) =>
      _$DiscoverModelFromJson(json);
}

@JsonSerializable()
class DiscoverResult {
  @JsonKey(name: "data")
  SmallCaseData? smallCaseData;

  DiscoverResult({this.smallCaseData});

  factory DiscoverResult.fromJson(Map<String, dynamic> json) =>
      _$DiscoverResultFromJson(json);
}

@JsonSerializable()
class SmallCaseData {
  @JsonKey(name: "smallcases")
  List<SmallCases>? listOfSmallcases;

  SmallCaseData({this.listOfSmallcases});

  factory SmallCaseData.fromJson(Map<String, dynamic> json) =>
      _$SmallCaseDataFromJson(json);
}

@JsonSerializable()
class SmallCases {
  @JsonKey(name: "_id")
  String? id;

  BenchMark? benchmark;
  Info? info;
  String? scid;
  String? rationale;
  int? version;
  Stats? stats;

  SmallCases(
      {this.id,
      this.benchmark,
      this.info,
      this.scid,
      this.rationale,
      this.version,
      this.stats});

  factory SmallCases.fromJson(Map<String, dynamic> json) =>
      _$SmallCasesFromJson(json);
}

@JsonSerializable()
class Stats {
  num? divReturns;
  num? indexValue;
  num? lastCloseIndex;
  num? launchDateIndex;
  num? minInvestAmount;
  bool? minInvestAmountOverridden;
  num? minSipAmount;
  num? unadjustedIndex;
  Ratios? ratios;
  CAGRReturns? returns;
  num? pe;

  Stats(
      {this.divReturns,
      this.indexValue,
      this.lastCloseIndex,
      this.launchDateIndex,
      this.minInvestAmount,
      this.minInvestAmountOverridden,
      this.minSipAmount,
      this.unadjustedIndex,
      this.ratios,
      this.pe});

  factory Stats.fromJson(Map<String, dynamic> json) => _$StatsFromJson(json);
}

@JsonSerializable()
class CAGRReturns {
  num? daily;
  num? fiveYear;
  num? halfyearly;
  num? monthly;
  num? quarterly;
  num? sinceInception;
  num? sinceLaunch;
  num? threeYear;
  num? weekly;
  num? yearly;

  num? get getMonthlyCAGRPercent =>
      this.monthly != null ? (this.monthly! * 100) : null;
  num? get getYearlyCAGRPercent =>
      this.yearly != null ? (this.yearly! * 100) : null;
  num? get getThreeYearCAGRPercent =>
      this.threeYear != null ? (this.threeYear! * 100) : null;

  CAGRReturns(
      {this.daily,
      this.fiveYear,
      this.halfyearly,
      this.monthly,
      this.quarterly,
      this.sinceInception,
      this.sinceLaunch,
      this.threeYear,
      this.weekly,
      this.yearly});
  factory CAGRReturns.fromJson(Map<String, dynamic> json) =>
      _$CAGRReturnsFromJson(json);
}

@JsonSerializable()
class Ratios {
  @JsonKey(name: "52wHigh")
  num? fiftyTwowHigh;
  @JsonKey(name: "52wLow")
  num? fiftyTwoLow;

  num? cagr;

  String? cagrDuration;
  num? divYield;
  num? divYieldDifferential;
  num? ema;
  num? largeCapPercentage;
  num? lastCloseEma;
  String? marketCapCategory;
  num? midCapPercentage;
  num? momentum;
  bool? oneYearLiveHistory;
  num? pb;
  num? pbDiscount;
  num? pe;
  num? peDiscount;
  num? risk;
  String? riskLabel;
  num? smallCapPercentage;

  //num? get getCAGRPercent=>this.cagr!=null?(this.cagr!*100):null;

  Ratios(
      {this.fiftyTwoLow,
      this.fiftyTwowHigh,
      this.cagr,
      this.cagrDuration,
      this.divYield,
      this.divYieldDifferential,
      this.ema,
      this.largeCapPercentage,
      this.lastCloseEma,
      this.marketCapCategory,
      this.midCapPercentage,
      this.momentum,
      this.oneYearLiveHistory,
      this.pb,
      this.pbDiscount,
      this.pe,
      this.peDiscount,
      this.risk,
      this.riskLabel,
      this.smallCapPercentage});

  factory Ratios.fromJson(Map<String, dynamic> json) => _$RatiosFromJson(json);
}

@JsonSerializable()
class Info {
  String? created;
  String? imageUrl;
  String? name;
  String? nextUpdate;
  String? publisherName;
  String? rebalanceSchedule;
  String? shortDescription;
  String? type;
  String? uploaded;

  Info(
      {this.created,
      this.imageUrl,
      this.name,
      this.nextUpdate,
      this.publisherName,
      this.rebalanceSchedule,
      this.shortDescription,
      this.type,
      this.uploaded});

  factory Info.fromJson(Map<String, dynamic> json) => _$InfoFromJson(json);
}

@JsonSerializable()
class BenchMark {
  String? benchmarkLabel;
  String? id;
  String? index;
  String? message;
  String? msg;

  BenchMark({this.benchmarkLabel, this.index, this.id, this.message, this.msg});
  factory BenchMark.fromJson(Map<String, dynamic> json) =>
      _$BenchMarkFromJson(json);
}
