import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/ui/smallcase_card_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/home_header_card_desc.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/home_promotion_card_desc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../../lic/lic_card.dart';

class DiscoverWidget extends StatelessWidget {
  const DiscoverWidget({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      scrollDirection: Axis.vertical,
      child: Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
        const SizedBox(
          height: 16,
        ),
        const LICCard(),
        const SizedBox(
          height: 16,
        ),
        const HomePromotionCardDesc(),
        const SizedBox(
          height: 16,
        ),
        Padding(
          padding: const EdgeInsets.only(top: 16.0, left: 18, right: 18),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                Translations.of(context).discoverCS,
                // "Discover Chhotastock",
                style: const TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.w500,
                ),
              ),
              const SizedBox(
                height: 8,
              ),
              Container(
                color: Colors.black,
                height: 2,
                width: 70,
              ),
              const SizedBox(
                height: 8,
              ),
            ],
          ),
        ),
        const DiscoverListWidget(),
        const SizedBox(
          height: 16,
        ),
      ]),
    );
  }
}

class DiscoverListWidget extends StatelessWidget {
  const DiscoverListWidget({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<DiscoverCubit, DiscoverState>(builder: (context, state) {
      if (state is DiscoverSuccess &&
          state.discoverResult.smallCaseData?.listOfSmallcases != null) {
        return Wrap(
          // mainAxisSize: MainAxisSize.min,
          children: [
            _DiscoverWidget(
                listOfSmallcases:
                    state.discoverResult.smallCaseData!.listOfSmallcases!),
          ],
        );
      } else if (state is DiscoverFailed) {
        return const ChhotaStocksErrorWidget();
      }

      return Wrap(
        children: const [
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 20.0, vertical: 20),
            child: ShimmerLoader(),
          ),
        ],
      );
    });
  }
}

class _DiscoverWidget extends StatefulWidget {
  final List<SmallCases> listOfSmallcases;

  const _DiscoverWidget({Key? key, required this.listOfSmallcases})
      : super(key: key);

  @override
  State<_DiscoverWidget> createState() => _DiscoverWidgetState();
}

class _DiscoverWidgetState extends State<_DiscoverWidget> {
  @override
  Widget build(BuildContext context) {
    if (widget.listOfSmallcases.isEmpty) {
      return Container(
          height: 50,
          alignment: Alignment.center,
          child: Text(
            Translations.of(context).emptyBasket,
            overflow: TextOverflow.ellipsis,
            // "No Chhota Stocks available!"
          ));
    }

    return Container(
      height: 300,
      child: ListView.builder(
          itemCount: widget.listOfSmallcases.length,
          scrollDirection: Axis.horizontal,
          shrinkWrap: true,
          padding:
              const EdgeInsets.only(top: 0, bottom: 10.0, left: 10, right: 10),
          itemBuilder: (context, index) {
            return Padding(
              padding: const EdgeInsets.all(8.0),
              child: SmallcaseCardWidget(
                  smallCases: widget.listOfSmallcases[index]),
            );
          }),
    );
  }
}
