import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/more_details_widget.dart';
import 'package:flutter/material.dart';

class SmallcaseCardWidget extends StatelessWidget {
  final SmallCases smallCases;
  const SmallcaseCardWidget({Key? key, required this.smallCases})
      : super(key: key);

  Color? getRiskColor(String? riskLabel) {
    if (riskLabel == null || riskLabel.isEmpty) {
      return Colors.green;
    } else if (riskLabel.contains("Low")) {
      return Colors.green;
    } else if (riskLabel.contains("High")) {
      return Colors.red;
    }

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.75,
      margin: const EdgeInsets.all(0.0),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(10),
        border: Border.all(color: const Color(0xFFdde0e4)),
      ),
      child: InkWell(
        onTap: () {
          if (smallCases.scid != null && smallCases.benchmark?.index != null) {
            Navigator.push(
                context,
                MaterialPageRoute(
                    builder: (context) => MoreDetailsWidget(
                          scid: smallCases.scid!,
                          benchmarkId: smallCases.benchmark!.index!,
                        )));
          }
        },
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 0.0, vertical: 12.0),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            mainAxisSize: MainAxisSize.min,
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 12.0),
                    child: ErrorNetworkImageWidget(
                      src: smallCases.info!.imageUrl!,
                      width: 30,
                      height: 30,
                    ),
                  ),
                  Container(
                    padding: const EdgeInsets.all(8),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(3),
                      gradient: const LinearGradient(
                        colors: [
                          Color(0xFFf8da96),
                          Color(0xFFf8da96),
                        ],
                        begin: FractionalOffset(0.0, 0.0),
                        end: FractionalOffset(1.0, 0.0),
                        stops: [0.0, 1.0],
                        tileMode: TileMode.clamp,
                      ),
                    ),
                    child: Text(
                      (smallCases.stats?.ratios?.riskLabel ?? "--"),
                      style: const TextStyle(
                        color: Colors.black,
                        fontSize: 12.0,
                        fontWeight: FontWeight.w400,
                      ),
                    ),
                  ),
                ],
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 12.0),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    const SizedBox(
                      height: 20,
                    ),
                    Row(children: [
                      Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        mainAxisSize: MainAxisSize.min,
                        children: [
                          Text(
                            smallCases.info?.name ?? "--",
                            overflow: TextOverflow.ellipsis,
                            style: const TextStyle(
                                fontSize: 16.0, fontWeight: FontWeight.w600),
                          ),
                          const SizedBox(
                            height: 4.0,
                          ),
                          Text(
                            "by ${smallCases.info?.publisherName ?? "--"}",
                            overflow: TextOverflow.ellipsis,
                            style: const TextStyle(
                              fontSize: 12.0,
                              fontWeight: FontWeight.w400,
                              color: Colors.grey,
                            ),
                          ),
                        ],
                      ),
                    ]),
                    const SizedBox(
                      height: 20,
                    ),
                    Text(
                      smallCases.info?.shortDescription ?? "",
                      style: const TextStyle(
                          fontSize: 14.0, fontWeight: FontWeight.w500),
                    ),
                    const SizedBox(
                      height: 20,
                    ),
                    if (smallCases.stats != null)
                      _BottomCard(
                        stats: smallCases.stats!,
                      ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class _BottomCard extends StatelessWidget {
  final Stats stats;
  const _BottomCard({Key? key, required this.stats}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisSize: MainAxisSize.min,
          children: [
            const Text(
              "1Y Returns",
              style: TextStyle(
                  fontSize: 12.0,
                  color: Colors.grey,
                  fontWeight: FontWeight.w400,
                  shadows: [
                    Shadow(
                      blurRadius: 1.0,
                      color: Colors.white24,
                      offset: Offset(1.0, 1.0),
                    ),
                  ]),
            ),
            const SizedBox(
              height: 8.0,
            ),
            InkWell(
              onTap: () {},
              child: Row(
                children: [
                  Text(
                    "${stats.returns?.getYearlyCAGRPercent?.toStringAsFixed(2) ?? "--"}%",
                    style: TextStyle(
                        color: stats.returns?.getYearlyCAGRPercent != null &&
                                stats.returns!.getYearlyCAGRPercent!.isNegative
                            ? Colors.red
                            : Colors.green,
                        fontSize: 14.0,
                        fontWeight: FontWeight.w600),
                  ),
                  const SizedBox(
                    width: 5,
                  ),
                  Tooltip(
                    waitDuration: const Duration(seconds: 1),
                    showDuration: const Duration(seconds: 5),
                    padding: const EdgeInsets.all(5),
                    height: 35,
                    textStyle: const TextStyle(
                      fontSize: 12,
                      color: Colors.white,
                      fontWeight: FontWeight.normal,
                    ),
                    triggerMode: TooltipTriggerMode.tap,
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: Colors.grey),
                    message:
                        '₹100 invested in this chhotastock 1 year back\nwould be ₹${(stats.returns!.getYearlyCAGRPercent! + 100).toStringAsFixed(2)} today as compared to ₹105.5 from FD',
                    child:const  Icon(
                      Icons.help,
                      size: 17,
                      color: Colors.grey,
                    ),
                  )
                ],
              ),
            ),
          ],
        ),
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Min. Amount",
              style: TextStyle(
                  fontSize: 12.0,
                  color: Colors.grey,
                  fontWeight: FontWeight.w400,
                  shadows: [
                    Shadow(
                      blurRadius: 1.0,
                      color: Colors.white24,
                      offset: Offset(1.0, 1.0),
                    ),
                  ]),
            ),
            const SizedBox(
              height: 8.0,
            ),
            Text(
              "₹ ${indiaFormat.format(stats.minInvestAmount).replaceAll("INR", "")}",
              style:
                  const TextStyle(fontSize: 14.0, fontWeight: FontWeight.w600),
            )
          ],
        ),
      ],
    );
  }
}
