import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/bloc/funds_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/bloc/init_sdk_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';

class FundsCard extends StatelessWidget {
  const FundsCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<FundsCubit, FundsState>(builder: (context, state) {
      if (state is FundsSuccess) {
        return Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(8),
              gradient: const LinearGradient(
                colors: [
                  Color(0xFFffe6a2),
                  Color(0xFFfdf0c7),
                ],
                begin: FractionalOffset(0.0, 0.0),
                end: FractionalOffset(1.0, 0.0),
                stops: [0.0, 1.0],
                tileMode: TileMode.clamp,
              ),
            ),
            height: 180,
            padding: const EdgeInsets.only(
                left: 18.0, right: 0.0, bottom: 22.0, top: 22.0),
            child: Stack(children: [
              Row(
                children: [
                  _ColumnCard(
                    title: Translations.of(context).funds,
                    isFunds: true,
                    subTitle:
                        "₹ ${indiaFormat.format(state.transactionCallbackOnSuccess.data?.funds).replaceAll("INR", "")}",
                    description:
                        state.transactionCallbackOnSuccess.broker ?? "--",
                  ),
                ],
              ),
              Positioned(
                  right: 10,
                  bottom: 0,
                  child: SvgPicture.network(
                    "https://assets.chhotastock.com/app/funds.svg",
                  ))
            ]));
      } else if (state is FundsLoading) {
        return const ShimmerLoader(
          height: 165,
          borderRadius: 8.0,
          color:   Color(0xFFffe6a2),
        );
      }

      return Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(8),
            gradient: const LinearGradient(
              colors: [
                Color(0xFFffe6a2),
                Color(0xFFfdf0c7),
              ],
              begin: FractionalOffset(0.0, 0.0),
              end: FractionalOffset(1.0, 0.0),
              stops: [0.0, 1.0],
              tileMode: TileMode.clamp,
            ),
          ),
          height: 180,
          padding: const EdgeInsets.only(
              left: 18.0, right: 0.0, bottom: 22.0, top: 22.0),
          child: Stack(children: [
            Row(
              children: [
                _ColumnCard(
                    title: Translations.of(context).funds,
                    isFunds: true,

                    //"Funds",
                    subTitle: "₹ --",
                    description: Translations.of(context).noBrokerConnected
                    //"No broker connected",
                    ),
              ],
            ),
            Positioned(
                right: 10,
                bottom: 0,
                child: SvgPicture.network(
                  "https://assets.chhotastock.com/app/funds.svg",
                  width: 120,
                  height: 120,
                ))
          ]));
    });
  }
}

class RefreshBtn extends StatelessWidget {
  const RefreshBtn({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<InitSdkCubit, InitSdkState>(builder: (context, state) {
      if (state is InitSdkSuccess && !state.isGuestUser) {
        return InkWell(
          onTap: () => BlocProvider.of<FundsCubit>(context).portfolioFunds(),
          child: Card(
            elevation: 1,
            color: Color(0xFFffe6a2).withOpacity(0.5),
            child: const Icon(
              Icons.refresh,
              color: Colors.black,
              size: 30,
            ),
          ),
        );
      }

      return const SizedBox();
    });
  }
}

class _ColumnCard extends StatelessWidget {
  final String title;
  final String subTitle;
  final String description;
  final bool isFunds;
  const _ColumnCard({
    Key? key,
    required this.title,
    required this.subTitle,
    required this.description,
    this.isFunds = false,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "Check FAQs on how to add\n& withdraw funds",
          style: const TextStyle(
            fontSize: 12.0,
            fontWeight: FontWeight.normal,
            color: Colors.black,
          ),
          overflow: TextOverflow.ellipsis,
        ),
        const SizedBox(
          height: 10.0,
        ),
        Row(mainAxisAlignment: MainAxisAlignment.start, children: [
          Text(
            title,
            style: const TextStyle(
              fontSize: 16.0,
              fontWeight: FontWeight.bold,
              color: Colors.black,
            ),
            overflow: TextOverflow.ellipsis,
          ),
          const SizedBox(
            width: 5.0,
          ),
          isFunds
              ? const RefreshBtn()
              : const SizedBox(
                  width: 0,
                ),
        ]),
        const SizedBox(
          height: 5.0,
        ),
        Text(
          subTitle,
          style: const TextStyle(
            fontSize: 20.0,
            fontWeight: FontWeight.w600,
            color: Colors.black,
          ),
          overflow: TextOverflow.ellipsis,
        ),
        const SizedBox(
          height: 5.0,
        ),
        Text(
          description,
          style: const TextStyle(
            fontSize: 11.0,
            fontWeight: FontWeight.normal,
            color: Colors.black,
          ),
          overflow: TextOverflow.ellipsis,
        ),
      ],
    );
  }
}
