import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/more_details_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';

class HomePromotionCardDesc extends StatelessWidget {
  const HomePromotionCardDesc({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<DiscoverCubit, DiscoverState>(builder: (context, state) {
      if (state is DiscoverSuccess &&
          state.discoverResult.smallCaseData?.listOfSmallcases != null) {
        return _HomePromotionCardDesc(
          showBuyButton:
              state.discoverResult.smallCaseData!.listOfSmallcases!.isNotEmpty,
          onTap: () {
            if (state.discoverResult.smallCaseData!.listOfSmallcases!
                    .isNotEmpty &&
                state.discoverResult.smallCaseData!.listOfSmallcases![0].scid !=
                    null &&
                state.discoverResult.smallCaseData!.listOfSmallcases![0]
                        .benchmark!.index !=
                    null) {
              Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => MoreDetailsWidget(
                            scid: state.discoverResult.smallCaseData!
                                .listOfSmallcases![0].scid!,
                            benchmarkId: state.discoverResult.smallCaseData!
                                .listOfSmallcases![0].benchmark!.index!,
                          )));
            }
          },
        );
      }

      return const _HomePromotionCardDesc(showBuyButton: false);
    });
  }
}

class _HomePromotionCardDesc extends StatelessWidget {
  final bool showBuyButton;
  final VoidCallback? onTap;
  const _HomePromotionCardDesc(
      {Key? key, required this.showBuyButton, this.onTap})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Container(
        height: 165,
        padding: const EdgeInsets.symmetric(horizontal: 18),
        child: Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(8),
            gradient: const LinearGradient(
              colors: [
                Color(0xFFf0f1fc),
                Color(0xFFf0f1fc),
              ],
              begin: FractionalOffset(0.0, 0.0),
              end: FractionalOffset(1.0, 0.0),
              stops: [0.0, 1.0],
              tileMode: TileMode.clamp,
            ),
          ),
          child: Stack(
            children: [
              const HomeStockIcon(stockName: "INFY", right: 90, bottom: 55),
              const HomeStockIcon(stockName: "ITC", right: 50, bottom: 35),
              const HomeStockIcon(stockName: "TCS", right: 5, bottom: 60),
              const HomeStockIcon(stockName: "WIPRO", right: 5, bottom: 105),
              const HomeStockIcon(stockName: "lt", right: 5, bottom: 15),
              const HomeStockIcon(
                  stockName: "BAJAJAUTO", right: 50, bottom: 85),
              Container(
                  padding: const EdgeInsets.only(
                      top: 18, bottom: 18, left: 18, right: 120),
                  child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Row(children: [
                          const ErrorNetworkImageWidget(
                            src:
                                "https://assets.chhotastock.com/app/chhota-stock.png",
                            height: 15,
                          ),
                          const SizedBox(
                            width: 10,
                          ),
                          SvgPicture.network(
                            "https://assets.chhotastock.com/app/chhota-stock-only-text.svg",
                            height: 10,
                          )
                        ]),
                        const SizedBox(
                          height: 20,
                        ),
                        const Text(
                          "Buy stocks of Top 25 Indian Companies at just ₹100",
                          style: TextStyle(
                            fontWeight: FontWeight.bold,
                            fontSize: 16,
                          ),
                        ),
                        const SizedBox(
                          height: 10,
                        ),
                        if (showBuyButton)
                          Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              children: const [
                                Text(
                                  "Buy Now",
                                  style: TextStyle(
                                    color: Color(0xFF4658d3),
                                    fontSize: 14,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                                Icon(
                                  Icons.chevron_right,
                                  color: Color(0xFF4658d3),
                                  size: 22,
                                )
                              ])
                      ])),
            ],
          ),
        ),
      ),
    );
  }
}

class HomeStockIcon extends StatelessWidget {
  final String? stockName;
  final double? right;
  final double? bottom;

  const HomeStockIcon({Key? key, this.stockName, this.right, this.bottom})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Positioned(
      right: right,
      bottom: bottom,
      child: Container(
        width: 40,
        height: 40,
        decoration: BoxDecoration(
            border: Border.all(
              color: Color(0xFFdbddfa),
              width: 2.0,
            ),
            borderRadius: BorderRadius.all(Radius.circular(40))),
        child: CircleAvatar(
          radius: 40,
          backgroundColor: Colors.transparent,
          child: ErrorNetworkImageWidget(
            src: "https://assets.chhotastock.com/app/stocks/${stockName}.png",
          ),
        ),
      ),
    );
  }
}
