import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/account/ui/account_home_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/ui/discover_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/faq/ui/faq.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/aggregated_bloc/aggregated_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/portfolio_summary/portfolio_summary_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/ui/investment/investment_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'home_app_bar.dart';

class HomeWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const HomeWidget({Key? key, this.onDone}) : super(key: key);

  @override
  State<HomeWidget> createState() => _HomeWidgetState();
}

class DecoratedTabBar extends StatelessWidget implements PreferredSizeWidget {
  final TabBar tabBar;
  final BoxDecoration decoration;

  const DecoratedTabBar({required this.tabBar, required this.decoration});

  @override
  Size get preferredSize => tabBar.preferredSize;

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Positioned.fill(child: Container(decoration: decoration)),
        tabBar,
      ],
    );
  }
}

class _HomeWidgetState extends State<HomeWidget> with TickerProviderStateMixin {
  int _selectedIndex = 0;
  List<Widget> homeWidgetsList = const [
    _DiscoverBody(),
    InvestmentWidget(),
    FAQ(),
    AccountHomeWidget(),
  ];
  @override
  void initState() {
    super.initState();
    context.read<DiscoverCubit>().discover();
    context.read<AggregatedCubit>().getPortfolioAggregate();
    context.read<PortfolioSummaryCubit>().portfolioSummary();
  }

    void _onItemTapped(int index) {
      setState(() {
        _selectedIndex = index;
      });
    }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final iconHeight = 24.0;
    return Material(
      child: RefreshIndicator(
        onRefresh: () async {
          context.read<DiscoverCubit>().discover();
          context.read<AggregatedCubit>().getPortfolioAggregate();
          context.read<PortfolioSummaryCubit>().portfolioSummary();
        },
        child: Scaffold(
          body: IndexedStack(
            index: _selectedIndex,
            children: homeWidgetsList,
          ),
          bottomNavigationBar: BottomNavigationBar(
            onTap: _onItemTapped,
            currentIndex: _selectedIndex,
            selectedFontSize: 12,
            selectedLabelStyle: const TextStyle(
              color: Color(0xFF4658d3),
              fontSize: 12,
              fontWeight: FontWeight.bold,
              overflow: TextOverflow.ellipsis
            ),
            selectedItemColor: Color(0xFF4658d3),
            unselectedLabelStyle: const TextStyle(
              color: Colors.grey,
              fontSize: 12,
              fontWeight: FontWeight.normal,
            ),
            type: BottomNavigationBarType.fixed,
            items: [
              BottomNavigationBarItem(
                activeIcon: SvgPicture.asset(
                  "assets/icons/navigate-circle.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Color(0xFF4658d3),
                ),
                icon: SvgPicture.asset(
                  "assets/icons/navigate-circle-outline.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Colors.grey,
                ),
                label: Translations.of(context).discover,
              ),
              BottomNavigationBarItem(
                icon: SvgPicture.asset(
                  "assets/icons/trending-up.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Colors.grey,
                ),
                activeIcon: SvgPicture.asset(
                  "assets/icons/trending-up-outline.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: const Color(0xFF4658d3),
                ),
                label: Translations.of(context).investment,
              ),
              BottomNavigationBarItem(
                activeIcon: SvgPicture.asset(
                  "assets/icons/book.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Color(0xFF4658d3),
                ),
                icon: SvgPicture.asset(
                  "assets/icons/book-outline.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Colors.grey,
                ),
                label: Translations.of(context).learnCTA,
                //'Learn',
              ),
              BottomNavigationBarItem(
                activeIcon: SvgPicture.asset(
                  "assets/icons/person-circle.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Color(0xFF4658d3),
                ),
                icon: SvgPicture.asset(
                  "assets/icons/person-circle-outline.svg",
                  package: "chhota_stocks_flutter",
                  height: iconHeight,
                  color: Colors.grey,
                ),
                label: Translations.of(context).account,
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class _DiscoverBody extends StatelessWidget {
  const _DiscoverBody({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return NestedScrollView(
      headerSliverBuilder: (context, innerBoxIsScrolled) {
        return [
          SliverToBoxAdapter(
            child: homeAppBar,
          ),
   
        ];
      },
      body: const DiscoverWidget(),
    );
  }
}
