import 'dart:convert';
import 'dart:ui';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

import '../commonWidget/src/web_view_widget.dart';
import '../initSDK/bloc/init_sdk_cubit.dart';
import '../initSDK/ui/home_header_card_desc.dart';
import '../saveLead/bloc/save_lead_cubit.dart';
import '../saveLead/model/leadgen_status_response.dart';

final baseImagePath="https://assets.chhotastock.com/app/";

class LICCard extends StatelessWidget {
  const LICCard({Key? key}):super(key: key);
  @override
  Widget build(BuildContext context) {



    return BlocBuilder<InitSdkCubit,InitSdkState>(
        builder: (context,state){
          if(state is InitSdkSuccess&&state.licLink!=null&&state.licLink!.isNotEmpty
              &&!ChhotaStocksConfig.getInstance().isGuestUser){
            return _LICReturningUserCard(onTap: (){
              Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) =>  WebviewWidget(
                          heading: "Subscribe IPOs", url: state.licLink!)));
            });

          }else if(state is InitSdkSuccess&&state.licLink!=null&&state.licLink!.isNotEmpty
              &&ChhotaStocksConfig.getInstance().isGuestUser){

            return const _LICNewUserCard();

          }else{
            return const HomeHeaderCardDesc();
          }
        }

    );



  }
}


class _LICNewUserCard extends StatelessWidget {
  const _LICNewUserCard({Key? key}):super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocProvider<SaveLeadCubit>(
      create: (context) => SaveLeadCubit(),
      child:_LICNewUserLogicCard(),
    );
  }
}

class _LICNewUserLogicCard extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return  _LICCard(onTap: (){
      ScgatewayFlutterPlugin.leadGenWithStatus(
          "", "", ChhotaStocksConfig.getInstance().mobile)
          .then((value) {
        if (value != null) {
          try {
            final response = jsonDecode(value);
            final responseData =
            LeadGenStatusResponse.fromJson(response);

            BlocProvider.of<SaveLeadCubit>(context).saveLead(
                leadId: responseData.leadId ?? "",
                status: responseData.status ?? "");
          } catch (e) {
            debugPrint("Leadgen call failed:${e}");
          }
        }else{
          BlocProvider.of<SaveLeadCubit>(context).saveLead(
              leadId: "",
              status:"");
        }
      });
    },isReturningUser: false,);
  }
}



class _LICCard extends StatelessWidget {
  final VoidCallback onTap;
  final bool isReturningUser;
  const _LICCard({Key? key,required this.onTap,required this.isReturningUser}):super(key: key);
  @override
  Widget build(BuildContext context) {

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 18),
      child: InkWell(
        onTap: onTap,
        child: Container(
          padding: const EdgeInsets.all(0.0),
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
              gradient:  LinearGradient(
                begin: Alignment.topLeft,
                end: Alignment.bottomRight,

                colors:  [
                  Color(0xfffdc062),
                  Color(0xfffdc062).withOpacity(0.8),
                  Color(0xfffdc062).withOpacity(0.5),
                  Color(0xfffdc062).withOpacity(0.3),
                  Color(0xfffdc062).withOpacity(0.1),


                  // Color(0xfffdc064).withOpacity(0.6),
                  // Color(0xfffdc064).withOpacity(0.5),
                ],
              ),

          ),
          child: Stack(
            children: [
              Align(
                alignment: Alignment.topLeft,
                child: Image.asset(
                  "assets/images/chhota-stock-logo.png",
                  package: "chhota_stocks_flutter",


                ),
              ),
              Padding(
                padding: const EdgeInsets.only(top: 8.0,left: 12.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const SizedBox(
                      height: 8,
                    ),
                    Padding(
                      padding: const EdgeInsets.only(right: 12.0),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          CachedNetworkImage(imageUrl:"${baseImagePath}lic_ipo_logo.webp",height: 40,width: 100),
                          const Text("Biggest IPO of India",style: const TextStyle(fontWeight: FontWeight.w600,fontSize: 14)),
                        ],
                      ),
                    ),
                    const SizedBox(
                      height: 8,
                    ),

                 Row(
                   mainAxisAlignment: MainAxisAlignment.spaceBetween,
                   crossAxisAlignment: CrossAxisAlignment.start,
                   children: [
                   Column(
                     crossAxisAlignment: CrossAxisAlignment.start,
                     children: [
                       const Text("India's biggest IPO is live\nfrom 4th May",style: const TextStyle(fontWeight: FontWeight.w700,fontSize: 14)),
                       const SizedBox(
                         height: 8,
                       ),
                       RichText(text: const TextSpan(
                           children:  [
                             TextSpan(text: "Open Demat Account Instantly with\n",style:  TextStyle(fontWeight: FontWeight.w400,fontSize: 10,color: Colors.black)),
                             TextSpan(text: "Chhotastock",style:  TextStyle(fontWeight: FontWeight.w700,fontSize: 10,color: Colors.black)),
                           ]
                       )),

                       const SizedBox(
                         height: 8,
                       ),
                       LicNewUserBottomBar(onTap: onTap,),

                     ],
                   ),
                   Image.asset(
                     "assets/images/chhota_boy.png",
                     package: "chhota_stocks_flutter",
                   ),
                 ],),

                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class LicNewUserBottomBar extends StatelessWidget {
  final String? title;
  final VoidCallback onTap;
  const LicNewUserBottomBar({Key? key,this.title,required this.onTap}):super(key: key);

  @override
  Widget build(BuildContext context) {

    return InkWell(
      onTap: onTap,
      child: Row(
        children: [
           Text(
            title??"Open Demat",
            overflow: TextOverflow.ellipsis,
            style:const TextStyle(
                fontSize: 14,
                fontFamily: "Inter-Regular-",
                color: Color(0xff384EC8),
                fontWeight: FontWeight.w500
            ),
            maxLines: 2,
            textAlign: TextAlign.center,
          ),
          const SizedBox(width: 12.0,),
          Icon(Icons.arrow_forward_ios_rounded,color: Theme.of(context).colorScheme.primaryColor,size: 14,),


        ],
      ),
    );
  }
}





class _ColumnCardTxt extends StatelessWidget {
  final String title;
  final String subTitle;
  const _ColumnCardTxt({Key? key,required this.title,required this.subTitle}):super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Text(title,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(
              fontSize: 12,
              fontFamily: "Inter-Medium",
              color: Colors.white
          ),),
        SizedBox(height: 8.0,),

        Text(subTitle,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(
              fontSize: 20,
              fontWeight:FontWeight.w800,
              //fontFamily: "Inter-ExtraBold",
              color: Colors.white
          ),),
      ],
    );
  }
}


class _LICReturningUserCard extends StatelessWidget {
  final VoidCallback onTap;

  const _LICReturningUserCard({Key? key,required this.onTap}):super(key: key);
  @override
  Widget build(BuildContext context) {

    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 18),
      child: InkWell(
        onTap: onTap,
        child: Container(
          padding: const EdgeInsets.all(0.0),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(10),
            gradient:  LinearGradient(
              begin: Alignment.topLeft,
              end: Alignment.bottomRight,

              colors:  [
                Color(0xff5295EA).withOpacity(0.1),


                Color(0xff5295EA).withOpacity(0.3),
                Color(0xff5295EA).withOpacity(0.5),
                Color(0xff5295EA).withOpacity(0.8),
                Color(0xff5295EA)


                // Color(0xfffdc064).withOpacity(0.6),
                // Color(0xfffdc064).withOpacity(0.5),
              ],
            ),

          ),
          child: Stack(
            children: [
              Align(
                alignment: Alignment.topRight,
                child: Image.asset(
                  "assets/images/chhota-stock-logo.png",
                  package: "chhota_stocks_flutter",


                ),
              ),
              Padding(
                padding: const EdgeInsets.only(top: 8.0,left: 12.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const SizedBox(
                      height: 8,
                    ),
                    Padding(
                      padding: const EdgeInsets.only(right: 12.0),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          CachedNetworkImage(imageUrl:"${baseImagePath}lic_ipo_logo.webp",height: 40,width: 100),
                          const Text("Biggest IPO of India",style: const TextStyle(fontWeight: FontWeight.w600,fontSize: 14)),
                        ],
                      ),
                    ),
                    const SizedBox(
                      height: 8,
                    ),

                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            const Text("India's biggest IPO is live\nfrom 4th May",style: const TextStyle(fontWeight: FontWeight.w700,fontSize: 14)),
                            const SizedBox(
                              height: 8,
                            ),
                            RichText(text: const TextSpan(
                                children:  [
                                  TextSpan(text: "Subscribe Instantly with\n",style:  TextStyle(fontWeight: FontWeight.w400,fontSize: 10,color: Colors.black)),
                                  TextSpan(text: "Chhotastock",style:  TextStyle(fontWeight: FontWeight.w700,fontSize: 10,color: Colors.black)),
                                ]
                            )),

                            const SizedBox(
                              height: 8,
                            ),
                            LicNewUserBottomBar(title: "Subscribe",onTap: onTap,),

                          ],
                        ),
                        Image.asset(
                          "assets/images/chhota_boy.png",
                          package: "chhota_stocks_flutter",
                        ),
                      ],),

                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}




