import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/bloc/more_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/etf_stock_data.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class HoldingChart extends StatelessWidget {
  final String keyName;
  final Stats? stats;
  final num? weight;
  const HoldingChart({
    Key? key,
    required this.keyName,
    required this.stats,
    required this.weight,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<MoreDetailsCubit, MoreDetailsState>(
        builder: (context, state) {
      if (state is MoreDetailsSuccess &&
          state.moreDetailsModel.holdings != null &&
          state.moreDetailsModel.holdings![keyName] != null &&
          state.moreDetailsModel.holdings![keyName] is List) {
        final data = state.moreDetailsModel.holdings![keyName].map((e) {
          final data = ETFStockData.fromJson(e);
          return data;
        }).toList();
        print(state.moreDetailsModel);
        return Column(children: [
          ...data.map(
            (stock) {
              return Container(
                  decoration: const BoxDecoration(
                      border: Border(
                          bottom: BorderSide(
                    width: 1.0,
                    color: Color(0xFFF1F1F1),
                  ))),
                  padding:
                      EdgeInsets.symmetric(vertical: 10.0, horizontal: 0.0),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Row(children: [
                        ErrorNetworkImageWidget(
                            width: 35,
                            height: 35,
                            src:
                                "https://assets.chhotastock.com/app/stocks/${stock.stock_symbol}.png"),
                        SizedBox(width: 15),
                        Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text(
                              stock.stock_symbol,
                              overflow: TextOverflow.ellipsis,
                            ),
                            Text(
                              stock.stock_name,
                              overflow: TextOverflow.ellipsis,
                              style: const TextStyle(
                                fontSize: 11.0,
                              ),
                            ),
                          ],
                        ),
                      ]),
                      Text(
                        "₹" +
                            (stock.pc_holding * stats!.minInvestAmount * weight)
                                .toStringAsFixed(2),
                        overflow: TextOverflow.ellipsis,
                        style: TextStyle(),
                      )
                    ],
                  ));
            },
          ),
          // Padding(
          //   padding: const EdgeInsets.only(top: 20.0),
          //   child: SfCartesianChart(
          //       primaryXAxis: CategoryAxis(
          //           title: AxisTitle(
          //               text: "Stock",
          //               textStyle: const TextStyle(
          //                 fontSize: 12,
          //               ))),
          //       primaryYAxis: CategoryAxis(
          //           title: AxisTitle(
          //               text: "%",
          //               textStyle: const TextStyle(
          //                 fontSize: 12,
          //               ))),
          //       series: <ChartSeries>[
          //         StackedBarSeries<ETFStockData, String>(
          //           dataSource: [
          //             ...state.moreDetailsModel.holdings![keyName].map((e) {
          //               final data = ETFStockData.fromJson(e);
          //               return data;
          //             }).toList()
          //           ],
          //           dataLabelSettings: const DataLabelSettings(
          //               textStyle: TextStyle(fontSize: 8.0),
          //               borderColor: Colors.black,
          //               isVisible: true,
          //               showCumulativeValues: true,
          //               labelPosition: ChartDataLabelPosition.outside),
          //           xValueMapper: (ETFStockData sales, _) => sales.stock_symbol,
          //           yValueMapper: (ETFStockData sales, _) =>
          //               sales.pc_holding != null ? sales.pc_holding! * 100 : 0,
          //         ),
          //       ]),
          // )
        ]);

        // return SfCircularChart(
        //   legend: Legend(isVisible: true),
        //   series: [
        //         PieSeries<ETFStockData,String>(
        //           dataSource: [
        //             ...state.moreDetailsModel.holdings![keyName].map((e){
        //               final data=ETFStockData.fromJson(e);
        //               return data;
        //             }).toList()
        //           ],
        //
        //
        //
        //             xValueMapper: (ETFStockData data, _) => "${data.stock_symbol} (${data.pc_holding!=null?(data.pc_holding!*100).toStringAsFixed(2):"--"} %)",
        //             yValueMapper: (ETFStockData data, _) => data.pc_holding,
        //             name: keyName
        //         ),
        //    ],
        // );

      }

      return const SizedBox();
    });
  }
}
