import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/more_details_model.dart';
import 'package:flutter/material.dart';

class MoreDetailsCard extends StatelessWidget {
  final MoreDetailsData moreDetailsData;

  const MoreDetailsCard({Key? key, required this.moreDetailsData})
      : super(key: key);

  Color? getRiskColor(String? riskLabel) {
    if (riskLabel == null || riskLabel.isEmpty) {
      return Colors.green;
    } else if (riskLabel.contains("Low")) {
      return Colors.green;
    } else if (riskLabel.contains("High")) {
      return Colors.red;
    }

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: const Color(0xFFF1F1F1),
      padding: const EdgeInsets.only(
          top: 20.0, left: 18.0, right: 18.0, bottom: 12.0),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Image.network(
                moreDetailsData.info!.imageUrl!,
                height: 50,
                width: 50,
                errorBuilder: (context, _, stack) {
                  return const ErrorImageWidget(
                    height: 50,
                    width: 50,
                  );
                },
              ),
              const SizedBox(
                width: 16.0,
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(
                    moreDetailsData.info?.name ?? "--",
                    style: const TextStyle(
                        fontSize: 18.0, fontWeight: FontWeight.w600),
                  ),
                  const SizedBox(
                    height: 12,
                  ),
                  Container(
                    width: MediaQuery.of(context).size.width / 1.4,
                    child: Text(
                      moreDetailsData.info?.shortDescription ?? "",
                      style: const TextStyle(
                          fontSize: 14.0, fontWeight: FontWeight.w500),
                    ),
                  ),
                  const SizedBox(
                    height: 12,
                  ),
                  Container(
                    padding: const EdgeInsets.all(8),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(3),
                      gradient: const LinearGradient(
                        colors: [
                          Color(0xFFf8da96),
                          Color(0xFFf8da96),
                        ],
                        begin: FractionalOffset(0.0, 0.0),
                        end: FractionalOffset(1.0, 0.0),
                        stops: [0.0, 1.0],
                        tileMode: TileMode.clamp,
                      ),
                    ),
                    child: Text(
                      (moreDetailsData.stats?.ratios?.riskLabel ?? "--"),
                      style: TextStyle(
                        color: Colors.black,
                        fontSize: 12.0,
                        fontWeight: FontWeight.w400,
                      ),
                    ),
                  ),
                  const SizedBox(
                    height: 12,
                  ),
                  if (moreDetailsData.stats != null)
                    _BottomCard(
                      stats: moreDetailsData.stats!,
                    ),
                ],
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class _BottomCard extends StatelessWidget {
  final Stats stats;
  const _BottomCard({Key? key, required this.stats}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
      children: [
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Min. Amount",
              style: TextStyle(
                  fontSize: 12.0,
                  color: Colors.grey,
                  fontWeight: FontWeight.w400,
                  shadows: [
                    Shadow(
                      blurRadius: 1.0,
                      color: Colors.white24,
                      offset: Offset(1.0, 1.0),
                    ),
                  ]),
            ),
            const SizedBox(
              height: 8.0,
            ),
            Text(
              "₹ ${indiaFormat.format(stats.minInvestAmount).replaceAll("INR", "")}",
              style:
                  const TextStyle(fontSize: 14.0, fontWeight: FontWeight.w600),
            )
          ],
        ),
        const SizedBox(
          width: 30,
        ),
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "1Y CAGR",
              style: TextStyle(
                  fontSize: 12.0,
                  color: Colors.grey,
                  fontWeight: FontWeight.w400,
                  shadows: [
                    Shadow(
                      blurRadius: 1.0,
                      color: Colors.white24,
                      offset: Offset(1.0, 1.0),
                    ),
                  ]),
            ),
            const SizedBox(
              height: 8.0,
            ),
            Text(
              "${stats.returns?.getYearlyCAGRPercent?.toStringAsFixed(2) ?? "--"} %",
              style: TextStyle(
                  color: stats.returns?.getYearlyCAGRPercent != null &&
                          stats.returns!.getYearlyCAGRPercent!.isNegative
                      ? Colors.red
                      : Colors.green,
                  fontSize: 14.0,
                  fontWeight: FontWeight.w600),
            )
          ],
        ),
      ],
    );
  }
}
