import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/overview.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/stocks_and_weight.dart';
import 'package:flutter/material.dart';

class MoreDetailsTab extends StatefulWidget {
  final Widget headerChild;

  const MoreDetailsTab({Key? key,required this.headerChild}) : super(key: key);

  @override
  State<MoreDetailsTab> createState() => _MoreDetailsTabState();
}


class _MoreDetailsTabState extends State<MoreDetailsTab>
    with TickerProviderStateMixin {
  late TabController _tabController;

  @override
  void initState() {
    super.initState();
    _tabController = TabController(length: 2, vsync: this, initialIndex: 0);
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return NestedScrollView(
      headerSliverBuilder: (context, value) {
        return [

          SliverToBoxAdapter(
            child:   widget.headerChild,
          ),


          SliverToBoxAdapter(
            child: PreferredSize(
                preferredSize: Size.fromHeight(50.0),
                child: Align(
                    alignment: Alignment.centerLeft,
                    child: DecoratedTabBar(
                      decoration: BoxDecoration(
                        border: Border(
                          bottom: BorderSide(
                            color: Colors.grey.withOpacity(0.2),
                            width: 1.0,
                          ),
                        ),
                      ),
                      tabBar: TabBar(
                        isScrollable: true,
                        indicator: const UnderlineTabIndicator(
                          borderSide: BorderSide(
                            width: 1,
                            color: Color(0xFF646464),
                          ),
                        ),
                        unselectedLabelColor: Colors.black,
                        padding: EdgeInsets.symmetric(horizontal: 18.0),
                        indicatorPadding:
                        const EdgeInsets.symmetric(horizontal: 12.0),
                        indicatorWeight: 1,
                        labelColor: const Color(0xFF207ae0),
                        controller: _tabController,
                        tabs: <Widget>[
                          Tab(
                            icon: Text(Translations.of(context).stocksAndWeight,
                                //"Stocks & Weights",
                                overflow: TextOverflow.ellipsis,
                                style: Theme.of(context)
                                    .appBarTheme
                                    .titleTextStyle
                                    ?.copyWith(
                                  fontSize: 14.0,
                                  fontWeight: FontWeight.normal,
                                )),
                          ),
                          Tab(
                            icon: Text(
                              Translations.of(context).overview,
                             // "Overview",
                              style: Theme.of(context)
                                  .appBarTheme
                                  .titleTextStyle
                                  ?.copyWith(
                                fontSize: 14.0,
                                fontWeight: FontWeight.normal,
                              ),
                            ),
                          ),
                        ],
                      ),
                    ))),
          ),
        ];
      },
      body:  Container(
        child: TabBarView(
          controller: _tabController,
          children: const <Widget>[
            Padding(
              padding: EdgeInsets.symmetric(vertical: 12.0),
              child: StocksAndWeight(),
            ),
            Padding(
              padding: EdgeInsets.symmetric(horizontal: 20.0, vertical: 12.0),
              child: Overview(),
            ),
          ],
        ),
      ),
    );


  }
}


class DecoratedTabBar extends StatelessWidget implements PreferredSizeWidget {
  final TabBar tabBar;
  final BoxDecoration decoration;

  DecoratedTabBar({required this.tabBar, required this.decoration});

  @override
  Size get preferredSize => tabBar.preferredSize;

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Stack(
        children: [
          Positioned.fill(child: Container(decoration: decoration)),
          tabBar,
        ],
      ),
    );
  }
}

