import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/chartDetails/bloc/chart_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/ui/invest_btn.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/bloc/more_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/news/bloc/news_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';

import 'more_details_card.dart';
import 'more_details_tab.dart';
import 'more_details_without_overview.dart';

class MoreDetailsWidget extends StatefulWidget {
  final String scid;
  final String? benchmarkId;
  final bool isWithoutOverview;
  const MoreDetailsWidget(
      {Key? key,
      required this.scid,
      this.isWithoutOverview = false,
      this.benchmarkId})
      : super(key: key);
  @override
  _MoreDetailsWidgetState createState() => _MoreDetailsWidgetState();
}

class _MoreDetailsWidgetState extends State<MoreDetailsWidget> {
  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: ()async{

        return false;
      },
      child: MultiBlocProvider(
          providers: [
            BlocProvider<MoreDetailsCubit>(
              create: (_) => MoreDetailsCubit(),
            ),
            BlocProvider<ChartDetailsCubit>(
              create: (_) => ChartDetailsCubit(),
            ),
            BlocProvider<NewsCubit>(create: (_) => NewsCubit())
          ],
          child: widget.isWithoutOverview && widget.benchmarkId == null
              ? MoreDetailsWithoutOverview(
                  scid: widget.scid,
                )
              : _MoreDetailsWidget(
                  scid: widget.scid,
                  benchmarkId: widget.benchmarkId!,
                )),
    );
  }
}

class _MoreDetailsWidget extends StatefulWidget {
  final String scid;
  final String benchmarkId;
  const _MoreDetailsWidget(
      {Key? key, required this.scid, required this.benchmarkId})
      : super(key: key);
  @override
  __MoreDetailsWidgetState createState() => __MoreDetailsWidgetState();
}

class __MoreDetailsWidgetState extends State<_MoreDetailsWidget> {
  @override
  void initState() {
    super.initState();
    BlocProvider.of<MoreDetailsCubit>(context)
        .getMoreDetailsOfSmallcase(scid: widget.scid);
    BlocProvider.of<ChartDetailsCubit>(context)
        .getChartDetails(scid: widget.scid, benchmarkId: widget.benchmarkId);
    BlocProvider.of<NewsCubit>(context).getNews(scid: widget.scid);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: ChhotaStocksTheme.lightThemeData
          .copyWith(appBarTheme: ChhotaStocksTheme.customAppBarTheme),
      child: Scaffold(
        resizeToAvoidBottomInset: false,
        floatingActionButtonLocation: FloatingActionButtonLocation.centerDocked,
        appBar: AppBar(
          elevation: 0,
          leading: IconButton(onPressed: ()=>Navigator.pop(context), icon: const Icon(Icons.arrow_back,color: Colors.black,)),

          title: SvgPicture.network(
            "https://assets.chhotastock.com/app/chhota-stock-only-text.svg",
          ),

          // backgroundColor: Theme.of(context).appBarTheme.backgroundColor,
        ),
        floatingActionButton: Align(
          alignment: Alignment.bottomCenter,
          child: InvestButtton(
            scid: widget.scid,
          ),
        ),
        body: BlocBuilder<MoreDetailsCubit, MoreDetailsState>(
            builder: (context, state) {
          if (state is MoreDetailsSuccess) {
            return MoreDetailsTab(
              headerChild: MoreDetailsCard(
                moreDetailsData: state.moreDetailsData,
              ),
            );
          } else if (state is MoreDetailsError) {
            return const ChhotaStocksErrorWidget();
          }

          return const Loader();
        }),
      ),
    );
  }
}
