import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/ui/invest_btn.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/bloc/more_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/stocks_and_weight.dart';
import 'package:chhota_stocks_flutter/src/feature/news/bloc/news_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/news/ui/new_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'more_details_card.dart';

class MoreDetailsWithoutOverview extends StatefulWidget {
  final String scid;
  const MoreDetailsWithoutOverview({Key? key, required this.scid})
      : super(key: key);
  @override
  _MoreDetailsWithoutOverviewState createState() =>
      _MoreDetailsWithoutOverviewState();
}

class _MoreDetailsWithoutOverviewState
    extends State<MoreDetailsWithoutOverview> {
  @override
  void initState() {
    super.initState();
    BlocProvider.of<MoreDetailsCubit>(context)
        .getMoreDetailsOfSmallcase(scid: widget.scid);
    BlocProvider.of<NewsCubit>(context).getNews(scid: widget.scid);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: ChhotaStocksTheme.lightThemeData
          .copyWith(appBarTheme: ChhotaStocksTheme.customAppBarTheme),
      child: Scaffold(
        appBar: AppBar(
          title: SvgPicture.network(
            "https://assets.chhotastock.com/app/chhota-stock-textonly.svg",
          ),
          leading: IconButton(icon:Icon(Icons.arrow_back),onPressed: ()=>Navigator.pop(context),),

          // backgroundColor: Theme.of(context).appBarTheme.backgroundColor,
        ),
        floatingActionButton: InvestButtton(
          scid: widget.scid,
        ),
        floatingActionButtonLocation: FloatingActionButtonLocation.centerDocked,
        body: BlocBuilder<MoreDetailsCubit, MoreDetailsState>(
            builder: (context, state) {
          if (state is MoreDetailsSuccess) {
            return SingleChildScrollView(
              child: Column(
                children: [
                  MoreDetailsCard(
                    moreDetailsData: state.moreDetailsData,
                  ),

                  const StocksAndWeight(
                    shrinkWrap: true,
                  ),
                  // const Padding(
                  //    padding: EdgeInsets.symmetric(horizontal: 20.0,vertical: 12.0),
                  //    child: Expanded(child: StocksAndWeight()),
                  //  ),

                  const Divider(
                    color: Colors.grey,
                  ),
                  const Padding(
                    padding:
                        EdgeInsets.symmetric(horizontal: 20.0, vertical: 12.0),
                    child: NewsWidget(),
                  ),
                ],
              ),
            );
          } else if (state is MoreDetailsError) {
            return const ChhotaStocksErrorWidget();
          }

          return const Loader();
        }),
      ),
    );
  }
}
