import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/bloc/more_details_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/more_details_model.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'holdings_chart.dart';

class StocksAndWeight extends StatelessWidget {
  final bool? shrinkWrap;
  const StocksAndWeight({Key? key, this.shrinkWrap}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<MoreDetailsCubit, MoreDetailsState>(
        builder: (context, state) {
      if (state is MoreDetailsSuccess &&
          state.moreDetailsData.segments != null &&
          state.moreDetailsData.segments!.isNotEmpty) {
        return ListView(
            shrinkWrap: shrinkWrap ?? false,
            physics: ClampingScrollPhysics(),
            children: [
              const SizedBox(
                height: 10,
              ),
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 18.0,),
                child: Text(
                  Translations.of(context).chhotaStocksInfo1,
                  // "Constituents of this Chhotastock were last reviewed on Dec 15 2021, and will be next reviewed on the Jan 15 2022",
                  style: const TextStyle(
                    fontSize: 14.0,
                  ),
                ),
              ),
              const SizedBox(
                height: 20,
              ),
             const _WhereitisInvestedCard(),
              Container(
                padding: const EdgeInsets.symmetric(
                    horizontal: 18.0, vertical: 14.0),
                decoration: const BoxDecoration(
                    border: Border(
                        bottom: BorderSide(
                  width: 1.0,
                  color: Colors.grey,
                ))),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text(
                      Translations.of(context).stocksAndSegment,
                      //  "Stocks & Segment",
                      overflow: TextOverflow.ellipsis,
                      style: Theme.of(context).textTheme.subtitle1?.copyWith(
                            fontSize: 14.0,
                            fontWeight: FontWeight.normal,
                          ),
                    ),
                    Text(
                      Translations.of(context).weightage,
                      //   "Weightage",
                      overflow: TextOverflow.ellipsis,
                      style: Theme.of(context).textTheme.subtitle1?.copyWith(
                            fontSize: 14.0,
                            fontWeight: FontWeight.normal,
                          ),
                    ),
                  ],
                ),
              ),
              ...state.moreDetailsData.segments!
                  .map((segments) => _SegmentWeightageHeading(
                      constituents: state.moreDetailsData.constituents,
                      data: segments.constituents,
                      stats: state.moreDetailsData.stats,
                      segment: segments.label ?? "--"))
                  .toList(),

              const SizedBox(
                height: 50,
              ),


            ]);
      }

      return Text(
        Translations.of(context).chhotaStocksInfo4,
        textAlign: TextAlign.center,
        // "Chhota Stocks will be added soon!"
        overflow: TextOverflow.ellipsis,
      );
    });
  }
}

class _SegmentWeightageHeading extends StatelessWidget {
  final String segment;
  final List<String>? data;
  final Stats? stats;
  final List<Constituents>? constituents;
  const _SegmentWeightageHeading({
    Key? key,
    required this.segment,
    required this.data,
    required this.stats,
    this.constituents,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if ((constituents == null && data == null) || constituents!.isEmpty) {
      return const SizedBox();
    }

    final constituentsData = constituents
        ?.where((element) => element.isConstituentOf(data))
        .toList();

    if (constituentsData == null || constituentsData.isEmpty) {
      return const SizedBox();
    }

    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 0.0),
      child: Column(
        children: [
          Container(
            color: const Color(0xFFF1F1F1),
            child: Padding(
              padding:
                  const EdgeInsets.only(top: 10.0, bottom: 10.0, left: 18.0),
              child: Row(
                children: [
                  Container(
                    width: 10,
                    height: 10,
                    decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                      color: Colors.purple,
                    ),
                  ),
                  const SizedBox(
                    width: 10,
                  ),
                  Text(
                    segment,
                    overflow: TextOverflow.ellipsis,
                    style:const  TextStyle(fontSize: 14),
                  )
                ],
              ),
            ),
          ),
          const SizedBox(
            height: 8.0,
          ),
          ...constituentsData.map((stock) {
            return Padding(
              padding:
                  const EdgeInsets.symmetric(vertical: 8.0, horizontal: 18.0),
              child: Column(
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      if (segment == "ETF Equity")
                        Expanded(
                          flex:2,
                          child: Text(
                            "via " + (stock.stockName ?? "--"),
                            overflow: TextOverflow.ellipsis,
                            style:
                                Theme.of(context).textTheme.subtitle1?.copyWith(
                                      fontSize: 12.0,
                                      fontWeight: FontWeight.w300,
                                      color: Colors.blue,
                                    ),
                          ),
                        ),
                      if (segment != "ETF Equity")
                        Expanded(
                          flex:2,
                          child: Text(
                            (stock.stockName ?? "--"),
                            overflow: TextOverflow.ellipsis,
                            style: const TextStyle(
                              fontSize: 14.0,
                              fontWeight: FontWeight.w100,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      if (segment != "ETF Equity")
                        Expanded(
                          flex:1,
                          child: Text(
                            "₹" +
                                (stock.weight! * stats!.minInvestAmount!)
                                    .toStringAsFixed(2),
                            overflow: TextOverflow.ellipsis,
                          textAlign:TextAlign.right,
                            style: const TextStyle(
                              fontSize: 14.0,
                              fontWeight: FontWeight.w100,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      // Text(
                      //   stock.weight != null
                      //       ? (stock.weight! * 100).toStringAsFixed(2)
                      //       : "--",
                      //   overflow: TextOverflow.ellipsis,
                      //   style: Theme.of(context).textTheme.subtitle1?.copyWith(
                      //       fontSize: 12.0, fontWeight: FontWeight.w300),
                      // ),
                    ],
                  ),
                  if (stock.ticker != null)
                    HoldingChart(
                      keyName: stock.ticker!,
                      stats: stats,
                      weight: stock.weight,
                    ),
                ],
              ),
            );
          }).toList()
        ],
      ),
    );
  }
}


class _WhereitisInvestedCard extends StatelessWidget {
  const _WhereitisInvestedCard({Key? key}):super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
      child: Card(
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10)),
       margin: const EdgeInsets.all(0.0),
        child: Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(8),
            gradient: const LinearGradient(
              colors: [
                Color(0xFFffe6a2),
                Color(0xFFfdf0c7),
              ],
              begin: FractionalOffset(0.0, 0.0),
              end: FractionalOffset(1.0, 0.0),
              stops: [0.0, 1.0],
              tileMode: TileMode.clamp,
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.symmetric(vertical: 12.0,horizontal: 12.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const  SizedBox(height: 12.0,),
                Text(
                  Translations.of(context).chhotaStocksInfo2,
                  overflow: TextOverflow.ellipsis,
                  //   "Where is it invested?",
                  textAlign: TextAlign.left,
                  style: Theme.of(context).textTheme.subtitle1?.copyWith(
                    fontSize: 16.0,
                    fontWeight: FontWeight.bold,
                  ),
                ),
              const  SizedBox(height: 12.0,),
                Text(
                  Translations.of(context).chhotaStocksInfo3,
                  // "Every unit purchased in this chhotastock is invested in multiple stocks & segments via ETF",
                  textAlign: TextAlign.left,
                  style: const TextStyle(
                    fontSize: 14.0,
                    fontWeight: FontWeight.normal,
                  ),
                ),

                SizedBox(height: 12.0,),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
