import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/web_view_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/news/models/news_model.dart';
import 'package:flutter/material.dart';

class NewsCard extends StatelessWidget {
  final NewsResultData newsResultData;

  const NewsCard({
    Key? key,
    required this.newsResultData,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        if (newsResultData.link != null && newsResultData.link!.isNotEmpty) {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => WebviewWidget(
                      heading: Translations.of(context).news, url: newsResultData.link!)));
        }
      },
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Image.network(
            newsResultData.imageUrl!,
            height: 80,
            width: 80,
            errorBuilder: (context, object, stack) {
              return const Icon(
                Icons.error_outline,
                size: 50,
              );
            },
          ),
          const SizedBox(
            width: 12,
          ),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  newsResultData.headline ?? "",
                  style: const TextStyle(
                    fontSize: 13.0,
                  ),
                ),
                const SizedBox(
                  height: 12.0,
                ),
                if (newsResultData.createdAt != null)
                  Text(
                    timeAgoSinceDate(newsResultData.createdAt!),
                    style: const TextStyle(
                      fontSize: 9.0,
                      color: Colors.grey,
                    ),
                  ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
