import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/ui/more_details_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/orderStatement/model/order_statement.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class AllBatchesWidget extends StatelessWidget {
  final InvestedSmallcases investedSmallcases;
  const AllBatchesWidget({Key? key, required this.investedSmallcases})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Theme(
      data: ChhotaStocksTheme.lightThemeData,
      child: Scaffold(
        appBar: AppBar(
          systemOverlayStyle: const SystemUiOverlayStyle(
            statusBarColor: Color(0xFFF1F1F1),
            statusBarIconBrightness: Brightness.dark,
            statusBarBrightness: Brightness.light,
          ),
          iconTheme: const IconThemeData(
            color: Colors.black, //change your color here
          ),
          backgroundColor: Color(0xFFF1F1F1),
          title: Text(
            Translations.of(context).allBatches,
            //  "All Batches",

            style: TextStyle(
              color: Colors.black,
            ),
          ),
        ),
        body: ListView(
          children: [
            Container(
              color: Color(0xFFF1F1F1),
              padding:
                  const EdgeInsets.symmetric(horizontal: 18.0, vertical: 12.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Row(
                    children: [
                      ErrorNetworkImageWidget(
                        src: investedSmallcases.imageUrl,
                        height: 35,
                      ),
                      const SizedBox(
                        width: 8.0,
                      ),
                      Text(
                        investedSmallcases.name ?? "",
                        overflow: TextOverflow.ellipsis,
                        style: const TextStyle(
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    width: 8.0,
                  ),
                  InkWell(
                    onTap: () {
                      if (investedSmallcases.scid != null) {
                        Navigator.push(
                            context,
                            MaterialPageRoute(
                                builder: (context) => MoreDetailsWidget(
                                    isWithoutOverview: true,
                                    scid: investedSmallcases.scid!)));
                      }
                    },
                    child: Container(
                      height: 40,
                      alignment: Alignment.center,
                      decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(8.0),
                          border: Border.all(
                            color: Colors.grey,
                          ),
                          color: Theme.of(context)
                              .floatingActionButtonTheme
                              .backgroundColor),
                      child: Padding(
                        padding: const EdgeInsets.symmetric(
                          horizontal: 20.0,
                        ),
                        child: Text(
                          Translations.of(context).track,
                          //  "Track",
                          overflow: TextOverflow.ellipsis,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            if (investedSmallcases.batches != null &&
                investedSmallcases.batches!.isNotEmpty)
              ...investedSmallcases.batches!
                  .map((e) => Container(
                      padding: const EdgeInsets.symmetric(
                          horizontal: 18.0, vertical: 9.0),
                      child: BatchCard(
                        batches: e,
                      )))
                  .toList()
                  .reversed
          ],
        ),
      ),
    );
  }
}

class BatchCard extends StatelessWidget {
  final Batches batches;
  const BatchCard({
    Key? key,
    required this.batches,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(10),
        border: Border.all(color: Color(0xFFdde0e4)),
      ),
      child: ExpansionTile(
        title: Title(
            color: Colors.white,
            child: batches.completedDate != null
                ? Padding(
                    padding: const EdgeInsets.only(top: 12.0),
                    child: Text(
                      formatDateToMMMDDYYYY(batches.completedDate),
                      overflow: TextOverflow.ellipsis,
                      style: const TextStyle(
                        fontSize: 11.0,
                        fontWeight: FontWeight.normal,
                      ),
                    ),
                  )
                : const SizedBox()),
        subtitle: Padding(
          padding: const EdgeInsets.symmetric(vertical: 12.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              _ColumnCard(
                  title: Translations.of(context).batch,
                  //"Batch",
                  subTitle: batches.label ?? "--"),
              _ColumnCard(
                  title: Translations.of(context).status,
                  //'Status',
                  subTitle: batches.status ?? "--"),
              if (batches.filled != null && batches.quantity != null)
                _ColumnCard(
                  title: "${batches.filled} of ${batches.quantity} filled",
                  subWidget: Container(
                    height: 12.0,
                    width: 40,
                    child: ClipRRect(
                      borderRadius: const BorderRadius.all(Radius.circular(10)),
                      child: LinearProgressIndicator(
                        value: batches.filled! / (batches.quantity as num),
                        minHeight: 12.0,
                        valueColor:
                            const AlwaysStoppedAnimation<Color>(Colors.green),
                        backgroundColor: const Color(0xffD6D6D6),
                      ),
                    ),
                  ),
                ),
            ],
          ),
        ),
        children: <Widget>[
          Padding(
            padding:
                const EdgeInsets.symmetric(horizontal: 8.0, vertical: 12.0),
            child: Table(
              children: [
                TableRow(
                    decoration: BoxDecoration(
                      border: Border(
                        bottom: BorderSide(
                          color: Color(0xFFF1F1F1),
                        ),
                      ),
                    ),
                    children: [
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(
                          Translations.of(context).stock,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                            fontSize: 11.0,
                            overflow: TextOverflow.ellipsis,
                            color: Colors.grey,
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(
                          Translations.of(context).avgPrice,
                          //   "Avg Price",
                          textAlign: TextAlign.end,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                            fontSize: 11.0,
                            overflow: TextOverflow.ellipsis,
                            color: Colors.grey,
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(
                          Translations.of(context).qtyFilled,
                          //  "Qty Filled",
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.end,
                          style: const TextStyle(
                            fontSize: 11.0,
                            overflow: TextOverflow.ellipsis,
                            color: Colors.grey,
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(vertical: 8.0),
                        child: Text(
                          Translations.of(context).qtyFilled,
                          //  "Qty Filled",
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.end,
                          style: const TextStyle(
                            fontSize: 11.0,
                            overflow: TextOverflow.ellipsis,
                            color: Colors.grey,
                          ),
                        ),
                      ),
                    ]),
                if (batches.orders != null && batches.orders!.isNotEmpty)
                  ...batches.orders!.map((order) {
                    return TableRow(
                        decoration: BoxDecoration(
                          border: batches.orders!.last != order
                              ? const Border(
                                  bottom: BorderSide(
                                    color: Color(0xFFF1F1F1),
                                  ),
                                )
                              : null,
                        ),
                        children: [
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              order.tradingsymbol ?? "--",
                              style: const TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              order.averagePrice?.toStringAsFixed(2) ?? "",
                              textAlign: TextAlign.end,
                              style: const TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              "${order.filledQuantity ?? "--"}/${order.quantity ?? "--"}",
                              textAlign: TextAlign.end,
                              style: const TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              order.transactionType ?? "--",
                              textAlign: TextAlign.end,
                              style: TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis,
                                  color: order.transactionType != null &&
                                          order.transactionType!.contains("BUY")
                                      ? Colors.green
                                      : Colors.red,
                                  fontWeight: FontWeight.w800),
                            ),
                          ),
                        ]);
                  }).toList(),

                if(batches.unplaced!=null&&batches.unplaced!.isNotEmpty)
                  ...batches.unplaced!.map((unplacedOrder){
                    return TableRow(
                        decoration: BoxDecoration(
                          border: batches.unplaced!.last != unplacedOrder
                              ? const Border(
                            bottom: BorderSide(
                              color: Color(0xFFF1F1F1),
                            ),
                          )
                              : null,
                        ),
                        children: [
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              unplacedOrder.tradingsymbol ?? "--",
                              style: const TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                         const  Padding(
                            padding:  EdgeInsets.symmetric(vertical: 8.0),
                            child:  Text(
                               "--",
                              textAlign: TextAlign.end,
                              style:  TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              "--/${unplacedOrder.quantity ?? "--"}",
                              textAlign: TextAlign.end,
                              style: const TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(vertical: 8.0),
                            child: Text(
                              unplacedOrder.transactionType ?? "--",
                              textAlign: TextAlign.end,
                              style: TextStyle(
                                  fontSize: 12.0,
                                  overflow: TextOverflow.ellipsis,
                                  color: unplacedOrder.transactionType != null &&
                                      unplacedOrder.transactionType!.contains("BUY")
                                      ? Colors.green
                                      : Colors.red,
                                  fontWeight: FontWeight.w800),
                            ),
                          ),
                        ]);
                  }).toList()
              ],
            ),
          ),
        ],
      ),
    );
  }
}

class _ColumnCard extends StatelessWidget {
  final String title;
  final String? subTitle;
  final Widget? subWidget;
  const _ColumnCard(
      {Key? key, required this.title, this.subTitle, this.subWidget})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          title,
          overflow: TextOverflow.ellipsis,
          style: const TextStyle(
            fontSize: 11.0,
            fontWeight: FontWeight.w400,
            color: Colors.grey,
          ),
        ),
        const SizedBox(
          height: 5.0,
        ),
        if (subTitle != null)
          Text(
            subTitle!,
            overflow: TextOverflow.ellipsis,
            style: const TextStyle(fontSize: 13.0, fontWeight: FontWeight.w500),
          ),
        if (subWidget != null) subWidget!,
        const SizedBox(
          height: 8.0,
        ),
      ],
    );
  }
}
