import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/orderStatement/bloc/order_statement_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'orders_list_widget.dart';

class OrderStatmentWidget extends StatelessWidget {
  final VoidCallback? onBack;
  const OrderStatmentWidget({Key? key,this.onBack}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: ()async{
         
        if(onBack==null){
          Navigator.pop(context);
        }else{
          onBack!();
        }
        
        return false;
      },
      child: BlocProvider<OrderStatementCubit>(
        create: (context) => OrderStatementCubit(),
        child: Theme(
            data: ChhotaStocksTheme.lightThemeData.copyWith(
                appBarTheme: ChhotaStocksTheme.customAppBarTheme
            ),
            child: Scaffold(
              appBar: AppBar(
                title: Text(
                Translations.of(context).orders,
                  overflow: TextOverflow.ellipsis,
                  //  "Orders",
                ),
                leading: IconButton(onPressed:(){
                  if(onBack==null){
                    Navigator.pop(context);
                  }else{
                    onBack!();
                  }
                }, icon: const Icon(Icons.arrow_back,size: 20,color: Colors.black,)),
              ),
              body: const _OrderStatmentWidget(),
            )),
      ),
    );
  }
}

class _OrderStatmentWidget extends StatefulWidget {
  const _OrderStatmentWidget({Key? key}) : super(key: key);

  @override
  State<_OrderStatmentWidget> createState() => _OrderStatmentWidgetState();
}

class _OrderStatmentWidgetState extends State<_OrderStatmentWidget> {
  @override
  void initState() {
    super.initState();
    BlocProvider.of<OrderStatementCubit>(context).getOrderStatement();
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<OrderStatementCubit, OrderStatementState>(
        builder: (context, state) {
      if (state is OrderStatementSuccess) {
        return OrdersListWidget(
            investedSmallcases: state.orderSatementData.investedSmallcases);
      } else if (state is OrderStatementError) {
        return const ChhotaStocksErrorWidget();
      }

      return const Loader();
    });
  }
}
