import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/more_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_aggregate_model.dart';
import 'package:json_annotation/json_annotation.dart';


part 'portfolio_summary_model.g.dart';
@JsonSerializable()
class PortfolioSummaryModel{
  int? code;
  String? errors;
  bool? success;

  @JsonKey(name:"data")
  List<PortfolioSummaryData?>? portfolioSummaryDataList;

  PortfolioSummaryModel({this.code,this.errors,this.success,this.portfolioSummaryDataList});

  PortfolioSummaryModel.withError({String errorMsg="Something went wrong."}):
        this.errors=errorMsg;

  factory PortfolioSummaryModel.fromJson(Map<String, dynamic> json) => _$PortfolioSummaryModelFromJson(json);




}

@JsonSerializable()
class PortfolioSummaryData{
  Investment? investment;
  PendingActions? actions;

  PortfolioSummaryData({this.investment,this.actions});

  factory PortfolioSummaryData.fromJson(Map<String, dynamic> json) => _$PortfolioSummaryDataFromJson(json);
}


@JsonSerializable()
class PendingActions{

  List<Fix>? fix;

  List<Fix>? rebalance;
  List<Fix>? sip;

  PendingActions({this.fix,this.rebalance,this.sip});

  factory PendingActions.fromJson(Map<String, dynamic> json) => _$PendingActionsFromJson(json);



}


@JsonSerializable()
class Fix{
  String? batchId;
  String? date;
  int? filled;
  bool? hidden;
  String? iscid;
  String? iscidObj;
  String? name;
  String? originalLabel;
  int? quantity;
  String? scid;
  String? source;

  Fix({this.batchId,this.date,this.filled,this.hidden,this.iscid,this.iscidObj,
    this.name,this.originalLabel,this.quantity,this.scid,this.source});

  factory Fix.fromJson(Map<String, dynamic> json) => _$FixFromJson(json);


}


@JsonSerializable()
class Investment{
  CurrentConfig? currentConfig;
  String? date;
  Flags? flags;

  String? imageUrl;
  String? iscid;
  String? name;
  String? recommendedAction;
  Returns? returns;
  String? scid;
  String? shortDescription;
  Stats? stats;
  String? status;
  int? version;



  Investment({this.currentConfig,this.date,this.flags,this.imageUrl,this.iscid,this.name,this.recommendedAction,this.returns,this.scid,
  this.shortDescription,this.stats,this.status,this.version});

  factory Investment.fromJson(Map<String, dynamic> json) => _$InvestmentFromJson(json);
}

@JsonSerializable()
class Returns{
  num? accruedDivReturns;

  AccuredReturns? accruedReturns;
  num? creditedDivReturns;
  AccuredReturns? creditedReturns;
  num? divReturns;
  Aggregate? insights;
  num? monthly;
  num? networth;
  num? otherReturns;
  num? realizedInvestment;
  num? realizedReturns;
  num? unrealizedInvestment;
  num? weekly;




  Returns({this.accruedDivReturns,this.accruedReturns,this.creditedDivReturns,this.creditedReturns,this.divReturns,this.insights,this.monthly,this.networth,
  this.otherReturns,this.realizedInvestment,this.realizedReturns,this.unrealizedInvestment,this.weekly});
  factory Returns.fromJson(Map<String, dynamic> json) => _$ReturnsFromJson(json);

}

@JsonSerializable()
class AccuredReturns{
  num? DSPL;
  num? LBES;

  AccuredReturns({this.DSPL,this.LBES});

  factory AccuredReturns.fromJson(Map<String, dynamic> json) => _$AccuredReturnsFromJson(json);

}



@JsonSerializable()
class CurrentConfig{
   List<Constituents?>? constituents;

   CurrentConfig({this.constituents});

   factory CurrentConfig.fromJson(Map<String, dynamic> json) => _$CurrentConfigFromJson(json);
}