import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/createTransaction/ui/exit_btn.dart';
import 'package:chhota_stocks_flutter/src/feature/moreDetails/model/more_details_model.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_summary_model.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'investment_card.dart';

class InvestmentDetails extends StatelessWidget {
  final Investment investment;
  final num? indexPercentChange;
  const InvestmentDetails(
      {Key? key, required this.investment, this.indexPercentChange})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: ()async{
        return false;
      },
      child: Theme(
        data: ChhotaStocksTheme.lightThemeData
            .copyWith(appBarTheme: ChhotaStocksTheme.customAppBarTheme),
        child: Scaffold(
          appBar: AppBar(
            title: Text(
              Translations.of(context).details,
              //"Details",
              overflow: TextOverflow.ellipsis,
              style: TextStyle(color: Colors.black),
            ),

            leading: IconButton(onPressed:()=>Navigator.pop(context) ,icon: const Icon(Icons.arrow_back),),
          ),
          body: ListView(
            children: [
              Container(
                color: const Color(0xFFF1F1F1),
                child: Padding(
                  padding: const EdgeInsets.all(18.0),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      ErrorNetworkImageWidget(
                        src: investment.imageUrl ?? "",
                        width: 40,
                        height: 40,
                      ),
                      const SizedBox(
                        width: 16.0,
                      ),
                      Flexible(
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              investment.name ?? "--",
                              overflow: TextOverflow.ellipsis,
                              style: const TextStyle(
                                  fontSize: 16.0, fontWeight: FontWeight.w600),
                            ),
                            const SizedBox(
                              height: 10.0,
                            ),
                            Text(
                              investment.shortDescription ?? "--",
                              style: const TextStyle(
                                  fontSize: 13.0, fontWeight: FontWeight.w400),
                            ),
                            const SizedBox(
                              height: 20.0,
                            ),
                            Container(
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                                children: [
                                  ColumnCardInvestment(
                                    title: Translations.of(context).indexVal,
                                    subWidget: Row(
                                      children: [
                                        Text(
                                          "${investment.stats?.indexValue?.toStringAsFixed(2) ?? "--"}",
                                          style: const TextStyle(
                                              fontSize: 14.0,
                                              fontWeight: FontWeight.w500),
                                        ),
                                        if (indexPercentChange != null &&
                                            indexPercentChange!.isNegative)
                                          const Icon(
                                            Icons.arrow_drop_down,
                                            size: 20,
                                            color: Colors.red,
                                          )
                                        else
                                          const Icon(
                                            Icons.arrow_drop_up,
                                            size: 20,
                                            color: Colors.green,
                                          ),
                                        Text(
                                          "${indexPercentChange?.toStringAsFixed(2)}",
                                          style: TextStyle(
                                              fontSize: 12.0,
                                              fontWeight: FontWeight.w500,
                                              color: indexPercentChange != null &&
                                                      indexPercentChange!
                                                          .isNegative
                                                  ? Colors.red
                                                  : Colors.green),
                                        ),
                                      ],
                                    ),
                                  ),
                                  const SizedBox(
                                    width: 20.0,
                                  ),
                                  ColumnCardInvestment(
                                      title: "First Invested on",
                                      subTitle:
                                          formatDateToMMMDDYYYY(investment.date)),
                                ],
                              ),
                            ),
                          ],
                        ),
                      )
                    ],
                  ),
                ),
              ),
              if (investment.scid != null &&
                  investment.returns?.insights?.currentValue != null &&
                  (investment.returns!.insights!.currentValue! > 0))
                ExitButtton(
                  iscid: investment.iscid!,
                ),
              const SizedBox(
                height: 20,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16.0),
                child: Text(
                  Translations.of(context).performance,
                  //"Performance",

                  overflow: TextOverflow.ellipsis,
                  style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),
                ),
              ),
              const SizedBox(
                height: 20,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    ColumnCardInvestment(
                        title: Translations.of(context).currentVal,
                        subTitle:
                            "₹ ${investment.returns?.insights?.currentValue != null ? indiaFormat.format(investment.returns!.insights!.currentValue).replaceAll("INR", "") : "--"}"),
                    ColumnCardInvestmentWithPercent(
                      percent: investment.returns?.insights?.totalReturnsPercent,
                      title: Translations.of(context).totalReturns,
                      subWidgetWithColor: Text(
                        "₹ ${investment.returns?.insights?.totalReturns != null ? indiaFormat.format(investment.returns!.insights!.totalReturns).replaceAll("INR", "") : "--"}",
                        style: TextStyle(
                            color: investment.returns?.insights?.totalReturns !=
                                        null &&
                                    investment.returns!.insights!.totalReturns!
                                        .isNegative
                                ? Colors.red
                                : Colors.green,
                            fontSize: 14.0,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ],
                ),
              ),
              const SizedBox(
                height: 20,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    ColumnCardInvestment(
                        title: Translations.of(context).currentInv,
                        subTitle:
                            "₹ ${investment.returns?.insights?.currentInvestment != null ? indiaFormat.format(investment.returns!.insights!.currentInvestment).replaceAll("INR", "") : "--"}"),
                    ColumnCardInvestmentWithPercent(
                      percent:
                          investment.returns?.insights?.currentReturnsPercent,
                      title: Translations.of(context).currentReturns,
                      subWidgetWithColor: Text(
                        "₹ ${investment.returns?.insights?.currentReturns != null ? indiaFormat.format(investment.returns!.insights!.currentReturns).replaceAll("INR", "") : "--"}",
                        style: TextStyle(
                            color: investment.returns?.insights?.currentReturns !=
                                        null &&
                                    investment.returns!.insights!.currentReturns!
                                        .isNegative
                                ? Colors.red
                                : Colors.green,
                            fontSize: 14.0,
                            fontWeight: FontWeight.w500),
                      ),
                    ),
                  ],
                ),
              ),
              const SizedBox(
                height: 20,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16.0),
                child: ColumnCardInvestment(
                    title: Translations.of(context).realizedAndDiv,
                    //"Realized Returns + Dividends",
                    subTitle:
                        "₹ ${investment.returns?.realizedReturns != null ? indiaFormat.format(investment.returns!.realizedReturns).replaceAll("INR", "") : "--"} + ₹ ${investment.returns?.divReturns != null ? indiaFormat.format(investment.returns!.divReturns).replaceAll("INR", "") : "--"}"),
              ),
              const SizedBox(
                height: 20,
              ),
              if (investment.currentConfig?.constituents != null) const Divider(),
              if (investment.currentConfig?.constituents != null)
                ContituentStocks(
                  constituent: investment.currentConfig!.constituents!,
                )
            ],
          ),
        ),
      ),
    );
  }
}

class ContituentStocks extends StatelessWidget {
  final List<Constituents?> constituent;
  const ContituentStocks({Key? key, required this.constituent})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    if (constituent.isEmpty) {
      return const SizedBox();
    }
    return Column(
      children: [
        Padding(
          padding: const EdgeInsets.symmetric(horizontal: 16.0, vertical: 8.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                Translations.of(context).stocksAndETF,
                //"Stocks/ETFs",
                overflow: TextOverflow.ellipsis,
                style: TextStyle(
                    fontWeight: FontWeight.w600,
                    color: Theme.of(context).primaryColor,
                    fontSize: 12.0),
              ),
              Text(
                Translations.of(context).returns,
                //"Returns",
                overflow: TextOverflow.ellipsis,
                style: TextStyle(
                    fontWeight: FontWeight.w600,
                    color: Theme.of(context).primaryColor,
                    fontSize: 12.0),
              )
            ],
          ),
        ),
        const SizedBox(
          height: 20,
        ),
        ...constituent.map((e) {
          return ExpansionTile(
            title: Title(
              color: Colors.white,
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Expanded(
                      child: Text(
                    e?.stockName ?? "",
                    overflow: TextOverflow.ellipsis,
                    style: const TextStyle(fontSize: 12.0),
                  )),
                  if (e?.returns != null)
                    Text(
                      (e!.returns! * 100).toStringAsFixed(2) + "%",
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                          color:
                              e.returns!.isNegative ? Colors.red : Colors.green,
                          fontSize: 12.0),
                    ),
                ],
              ),
            ),
            children: [
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 16.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    _RowCard(
                      title: Translations.of(context).shares,
                      subTitle: e?.shares?.toString() ?? "--",
                    ),
                    _RowCard(
                      title: Translations.of(context).avgPrice,
                      subTitle:
                          ": ₹ ${e?.averagePrice != null ? indiaFormat.format(e!.averagePrice).replaceAll("INR", "") : "--"}",
                    ),
                  ],
                ),
              ),
              const SizedBox(
                height: 20,
              ),
            ],
          );
        }).toList()
      ],
    );
  }
}

class _RowCard extends StatelessWidget {
  final String title;
  final String subTitle;
  const _RowCard({Key? key, required this.title, required this.subTitle})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Text(
          title,
          style: TextStyle(fontSize: 10),
          overflow: TextOverflow.ellipsis,
        ),
        const SizedBox(
          width: 4,
        ),
        Text(
          subTitle,
          style: TextStyle(
              fontSize: 12, color: Colors.black, fontWeight: FontWeight.w600),
          overflow: TextOverflow.ellipsis,
        ),
      ],
    );
  }
}

class ColumnCardInvestmentWithPercent extends StatelessWidget {
  final String title;
  final String? subTitle;
  final Widget? subWidget;
  final Widget? subWidgetWithColor;
  final num? percent;
  const ColumnCardInvestmentWithPercent(
      {Key? key,
      required this.title,
      this.subTitle,
      this.subWidget,
      this.subWidgetWithColor,
      this.percent})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          children: [
            Text(
              title,
              style:
                  const TextStyle(fontSize: 12.0, fontWeight: FontWeight.w400),
            ),
            const SizedBox(
              width: 8.0,
            ),
            if (percent != null)
              Text(
                "${percent!.toStringAsFixed(2)} %",
                style: TextStyle(
                    fontSize: 12.0,
                    overflow: TextOverflow.ellipsis,
                    color: percent!.isNegative ? Colors.red : Colors.green,
                    fontWeight: FontWeight.w400),
              ),
          ],
        ),
        const SizedBox(
          height: 8.0,
        ),
        if (subTitle != null)
          Text(
            subTitle!,
            style: const TextStyle(fontSize: 16.0, fontWeight: FontWeight.w500),
          ),
        if (subWidgetWithColor != null) subWidgetWithColor!,
        if (subWidget != null) subWidget!,
        const SizedBox(
          height: 8.0,
        ),
      ],
    );
  }
}
