import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/portfolio_summary/portfolio_summary_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/model/portfolio_summary_model.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'investment_card.dart';

class InvestmentList extends StatelessWidget {
  const InvestmentList({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<PortfolioSummaryCubit, PortfolioSummaryState>(
        builder: (context, state) {
      if (ChhotaStocksConfig.getInstance().isGuestUser) {
        return Container(
          height: 50,
          alignment: Alignment.center,
          child: Text(
            Translations.of(context).noInvestmentYet,
            overflow: TextOverflow.ellipsis,
          ),
        );
      } else if (state is PortfolioSummarySuccess &&
          state.portfolioSummaryDataList != null) {
        return _InvestmentList(
          portfolioSummaryDataList: state.portfolioSummaryDataList,
        );
      } else if (state is PortfolioSummaryEmpty) {
        return Container(
          height: 50,
          alignment: Alignment.center,
          child: Text(
            Translations.of(context).noInvestmentYet,
            overflow: TextOverflow.ellipsis,
          ),
        );
      } else if (state is PortfolioSummaryError) {
        return Container(
          height: 80,
          child: ChhotaStocksErrorWidget(
            onPressed: () =>
                context.read<PortfolioSummaryCubit>().portfolioSummary(),
          ),
        );
      }

      return const Loader();
    });
  }
}

class _InvestmentList extends StatelessWidget {
  final List<PortfolioSummaryData?> portfolioSummaryDataList;
  const _InvestmentList({Key? key, required this.portfolioSummaryDataList})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    if (portfolioSummaryDataList.isNotEmpty) {
      return ListView.builder(
          itemCount: portfolioSummaryDataList.length,
          padding: const EdgeInsets.symmetric(horizontal: 14),
          shrinkWrap: true,
          itemBuilder: (context, index) {
            if (portfolioSummaryDataList[index] != null) {
              return InvestmentCard(
                portfolioSummaryData: portfolioSummaryDataList[index]!,
              );
            } else {
              return const SizedBox();
            }
          });
    }

    return Center(
      child: Text(
        Translations.of(context).noInvestmentYet,
        overflow: TextOverflow.ellipsis,
      ),
    );
  }
}
