import 'dart:convert';

import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/config/chhota_stocks_config.dart';
import 'package:chhota_stocks_flutter/src/feature/saveLead/bloc/save_lead_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/saveLead/model/leadgen_status_response.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

class LeadGenButton extends StatelessWidget {
  final bool isProfileBtn;
  final String? labelTxt;
  const LeadGenButton({Key? key,this.isProfileBtn=false,this.labelTxt}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocProvider<SaveLeadCubit>(
      create: (context) => SaveLeadCubit(),
      child: isProfileBtn?_LeadGenProfileBtn():_LeadGenBtn(labelTxt: labelTxt,),
    );
  }
}

class _LeadGenBtn extends StatelessWidget {
  final String? labelTxt;

  const _LeadGenBtn({Key? key,this.labelTxt}):super(key: key);

  @override
  Widget build(BuildContext context) {
    if (ChhotaStocksConfig.getInstance().isGuestUser != null &&
        ChhotaStocksConfig.getInstance().isGuestUser) {
      return Padding(
        padding: const EdgeInsets.only(top: 10.0),
        child: InkWell(
            child: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Text(
                    labelTxt??Translations.of(context).openAcc,
                    style: const TextStyle(
                      color: Colors.green,
                      fontSize: 14,
                      fontWeight: FontWeight.bold,
                    ),
                  ),
                  const Icon(
                    Icons.chevron_right,
                    color: Colors.green,
                    size: 22,
                  )
                ]),
            onTap: () async {
              ScgatewayFlutterPlugin.leadGenWithStatus(
                      "", "", ChhotaStocksConfig.getInstance().mobile)
                  .then((value) {
                if (value != null) {
                  try {
                    final response = jsonDecode(value);
                    final responseData =
                        LeadGenStatusResponse.fromJson(response);

                    BlocProvider.of<SaveLeadCubit>(context).saveLead(
                        leadId: responseData.leadId ?? "",
                        status: responseData.status ?? "");
                  } catch (e) {
                    debugPrint("Leadgen call failed:${e}");
                  }
                }else{
                  BlocProvider.of<SaveLeadCubit>(context).saveLead(
                      leadId: "",
                      status:"");
                }
              });
            }),
      );
    } else {
      return const SizedBox();
    }
  }
}


class _LeadGenProfileBtn extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    if (ChhotaStocksConfig.getInstance().isGuestUser != null &&
        ChhotaStocksConfig.getInstance().isGuestUser) {

      return Column(
        children: [
          InkWell(
            onTap: (){
              ScgatewayFlutterPlugin.leadGenWithStatus(
                  "", "", ChhotaStocksConfig.getInstance().mobile)
                  .then((value) {
                if (value != null) {
                  try {
                    final response = jsonDecode(value);
                    final responseData =
                    LeadGenStatusResponse.fromJson(response);

                    BlocProvider.of<SaveLeadCubit>(context).saveLead(
                        leadId: responseData.leadId ?? "",
                        status: responseData.status ?? "");
                  } catch (e) {
                    debugPrint("Leadgen call failed:${e}");
                  }
                }else{
                  BlocProvider.of<SaveLeadCubit>(context).saveLead(
                      leadId: "",
                      status:"");
                }
              });
            },
            child: ListTile(
              title: Text(
                Translations.of(context).openAcc,
                // "Orders",
                style: const TextStyle(
                  fontWeight: FontWeight.w400,
                  fontSize: 16.0,
                ),
              ),
              subtitle:const  Text(
                "Open account and start saving",
                //"Order history, status and more",
                style:  TextStyle(
                  fontWeight: FontWeight.normal,
                  fontSize: 11.0,
                ),
              ),
              trailing: const Icon(
                Icons.arrow_forward_ios_rounded,
                size: 20,
              ),
            ),
          ),
          const Divider(
            height: 4.0,
          ),
        ],
      );

    } else {
      return const SizedBox();
    }
  }
}

