import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/sipDetails/bloc/sip_details_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class SIPDetailsPage extends StatelessWidget {
  final String iscid;
  final String name;
  const SIPDetailsPage({Key? key,required this.iscid,required this.name}):super(key: key);
  @override
  Widget build(BuildContext context) {
    return  Material(
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 18.0,vertical: 18.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisSize: MainAxisSize.min,
          children: [
            const SizedBox(height: 12,),
            Text(name,style: const TextStyle(fontSize: 18.0,fontWeight: FontWeight.w500),),
            const SizedBox(height: 4,),
            const  Text("SIP Details",style: TextStyle(fontSize: 8.0),),

            const SizedBox(height: 12,),
            const Divider(color: Color(0xFFdde0e4),),
            const SizedBox(height: 12,),
            BlocProvider<SipDetailsCubit>(
                create: (_)=>SipDetailsCubit(),
                child: _SIPDetailsPage(iscid: iscid,),


            ),
          ],
        ),
      ),
    );
  }
}


class _SIPDetailsPage extends StatefulWidget {
  final String iscid;
  const _SIPDetailsPage({Key? key,required this.iscid}):super(key: key);

  @override
  __SIPDetailsPageState createState() => __SIPDetailsPageState();
}

class __SIPDetailsPageState extends State<_SIPDetailsPage> {

  @override
  void initState(){
    super.initState();
    BlocProvider.of<SipDetailsCubit>(context).getSipDetails(iscid: widget.iscid);
  }

  @override
  Widget build(BuildContext context) {
    return  BlocBuilder<SipDetailsCubit,SipDetailsState>(
        builder: (context,state){
            if(state is SipDetailsSuccess&&state.sipDetails.sipData?.frequency!=null
                &&state.sipDetails.sipData?.scheduledDate!=null&&state.sipDetails.sipData!.scheduledDate!.isNotEmpty){

              return Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      const Text("Frequency",style: TextStyle(fontSize: 14,fontWeight: FontWeight.w300),),
                      const SizedBox(height: 8.0,),
                      Text(state.sipDetails.sipData!.frequency!.isNotEmpty?state.sipDetails.sipData!.frequency!.toUpperCase():"--"),
                    ],
                  ),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      const Text("Next Installment",style: TextStyle(fontSize: 14,fontWeight: FontWeight.w300),),
                      const SizedBox(height: 8.0,),
                      Text(formatDateToMMMDDYYYY(state.sipDetails.sipData!.scheduledDate!)),
                    ],
                  ),
                ],
              );

            }else if(state is SipDetailsError){
               return ChhotaStocksErrorWidget(
                 onPressed: ()=>BlocProvider.of<SipDetailsCubit>(context).getSipDetails(iscid: widget.iscid),
               );
            }

            return Container(
              height: 120,
              alignment: Alignment.center,
              child: const Text("Loading...",textAlign: TextAlign.center,),
            );



        }

    );
  }
}

